@@ -47,6 +47,8 @@ using namespace Peony::DirectoryView;
 
 IconViewIndexWidget::IconViewIndexWidget(const IconViewDelegate *delegate, const QStyleOptionViewItem &option, const QModelIndex &index, QWidget *parent) : QWidget(parent)
 {
+    installEventFilter(parent);
+
     setMouseTracking(true);
 
     m_edit_trigger.setInterval(3000);
@@ -139,13 +141,31 @@ IconViewIndexWidget::~IconViewIndexWidget()
     delete m_edit;
 }
 
+bool IconViewIndexWidget::eventFilter(QObject *watched, QEvent *event)
+{
+    if (event->type() == QEvent::Resize) {
+        adjustPos();
+        update();
+    }
+    return false;
+}
+
 void IconViewIndexWidget::paintEvent(QPaintEvent *e)
 {
+    IconView *view = m_delegate->getView();
+    auto expectedRect = view->visualRect(m_index);
+    auto rectPos = this->mapToParent(QPoint(0, 0));
+    if (expectedRect.topLeft() != rectPos) {
+        adjustPos();
+        update();
+        return;
+    }
+
     QWidget::paintEvent(e);
     QPainter p(this);
     //p.fillRect(0, 0, 999, 999, Qt::red);
 
-    adjustPos();
+    //adjustPos();
 
     //qDebug()<<m_option.backgroundBrush;
     //qDebug()<<this->size() << m_delegate->getView()->iconSize();
@@ -178,7 +198,7 @@ void IconViewIndexWidget::paintEvent(QPaintEvent *e)
 
     p.setPen(opt.palette.highlightedText().color());
     p.translate(0, m_delegate->getView()->iconSize().height() + 5);
-    IconViewTextHelper::paintText(&p, opt, m_index, 9999, 2, 0);
+    IconViewTextHelper::paintText(&p, opt, m_index, 9999, 2, 4);
 
 //    p.translate(-1, m_delegate->getView()->iconSize().height() + 13);
 //    //m_edit->document()->drawContents(&p);
@@ -198,7 +218,10 @@ void IconViewIndexWidget::paintEvent(QPaintEvent *e)
     // draw color symbols
     auto colors = info->getColors();
     int offset = 0;
-    for (auto color : colors) {
+    const int MAX_LABEL_NUM = 3;
+    int startIndex = (colors.count() > MAX_LABEL_NUM ? colors.count() - MAX_LABEL_NUM : 0);
+    for (int i = startIndex; i < colors.count(); ++i) {
+        auto color = colors.at(i);
         p.save();
         p.setRenderHint(QPainter::Antialiasing);
         p.translate(2, 2);
@@ -206,7 +229,7 @@ void IconViewIndexWidget::paintEvent(QPaintEvent *e)
         p.setBrush(color);
         p.drawEllipse(QRectF(offset, 0, 10, 10));
         p.restore();
-        offset += 10;
+        offset += 10/2;
     }
 
     //paint symbolic link emblems
