@@ -26,6 +26,7 @@
 #include "file-item-model.h"
 
 #include "list-view.h"
+#include "clipboard-utils.h"
 
 #include "file-info.h"
 
@@ -36,6 +37,7 @@
 
 #include <QKeyEvent>
 #include <QItemDelegate>
+#include <file-label-model.h>
 
 #include <QApplication>
 
@@ -51,30 +53,99 @@ ListViewDelegate::~ListViewDelegate()
     m_styled_button->deleteLater();
 }
 
+void ListViewDelegate::initIndexOption(QStyleOptionViewItem *option, const QModelIndex &index) const
+{
+    return initStyleOption(option, index);
+}
+
 void ListViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QStyleOptionViewItem opt = option;
     initStyleOption(&opt, index);
     opt.displayAlignment = Qt::Alignment(Qt::AlignLeft|Qt::AlignVCenter);
 
-    QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &opt, painter);
-
-    if (index.column() == 0) {
-        auto view = qobject_cast<DirectoryView::ListView *>(parent());
+    auto view = qobject_cast<DirectoryView::ListView *>(parent());
+    auto info = FileInfo::fromUri(index.data(Qt::UserRole).toString());
+    auto colors = info->getColors();
+    if (index.column() == 0 && colors.count() >0) {
         if (!view->isDragging() || !view->selectionModel()->selectedIndexes().contains(index)) {
-            auto info = FileInfo::fromUri(index.data(Qt::UserRole).toString());
-            auto colors = info->getColors();
-            int offset = 0;
-            for (auto color : colors) {
+            int xoffset = 5;
+            int yoffset = 0;
+            int index = 0;
+            const int MAX_LABEL_NUM = 3;
+            int startIndex = (colors.count() > MAX_LABEL_NUM ? colors.count() - MAX_LABEL_NUM : 0);
+
+            //set color label on center, fix bug#40609
+            auto iconSize = view->iconSize();
+            auto size = iconSize.height()/2;
+            auto labelSize = iconSize.height()/3;
+            if (labelSize > 10)
+                labelSize = 10;
+            if (labelSize <6)
+                labelSize = 6;
+            if (colors.count() == 1)
+                yoffset = size-labelSize/2;
+            else if (colors.count() == 2)
+                yoffset = size - labelSize;
+            else
+                yoffset = labelSize/2;
+
+            for (int i = startIndex; i < colors.count(); ++i, ++index) {
+                auto color = colors.at(i);
                 painter->save();
                 painter->setRenderHint(QPainter::Antialiasing);
                 painter->translate(0, opt.rect.topLeft().y());
                 painter->translate(2, 2);
                 painter->setPen(opt.palette.highlightedText().color());
                 painter->setBrush(color);
-                painter->drawEllipse(QRectF(offset, 0, 10, 10));
+                painter->drawEllipse(QRectF(xoffset, yoffset, labelSize, labelSize));
                 painter->restore();
-                offset += 10;
+                yoffset += labelSize/2;
+            }
+        }
+    }
+
+    if (ClipboardUtils::isClipboardHasFiles() &&
+        FileUtils::isSamePath(ClipboardUtils::getClipedFilesParentUri(), view->getDirectoryUri())) {
+        if (ClipboardUtils::isClipboardFilesBeCut()) {
+            auto clipedUris = ClipboardUtils::getClipboardFilesUris();
+            if (clipedUris.contains(FileUtils::urlEncode(index.data(Qt::UserRole).toString()))) {
+                painter->setOpacity(0.5);
+                qDebug()<<"cut item in list view"<<index.data();
+            }
+            else
+                painter->setOpacity(1.0);
+        }
+    }
+
+    QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &opt, painter);
+
+    //add link and read only icon support
+    if (index.column() == 0) {
+        auto rect = view->visualRect(index);
+        auto iconSize = view->iconSize();
+        auto size = iconSize.width()/2;
+        bool isSymbolicLink = info->isSymbolLink();
+        auto loc_x = rect.x() + iconSize.width() - size/2;
+        auto loc_y =rect.y();
+        //paint symbolic link emblems
+        if (isSymbolicLink) {
+            QIcon icon = QIcon::fromTheme("emblem-symbolic-link");
+            //qDebug()<<info->symbolicIconName();
+            icon.paint(painter, loc_x, loc_y, size, size);
+            //painter->restore();
+        }
+
+        //paint access emblems
+        //NOTE: we can not query the file attribute in smb:///(samba) and network:///.
+        loc_x = rect.x();
+        if (info->uri().startsWith("file:")) {
+            if (!info->canRead()) {
+                QIcon icon = QIcon::fromTheme("emblem-unreadable");
+                icon.paint(painter, loc_x, loc_y, size, size);
+            } else if (!info->canWrite() && !info->canExecute()) {
+                QIcon icon = QIcon::fromTheme("emblem-readonly");
+                icon.paint(painter, loc_x, loc_y, size, size);
             }
         }
     }
@@ -89,15 +160,15 @@ QWidget *ListViewDelegate::createEditor(QWidget *parent, const QStyleOptionViewI
     edit->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     edit->setWordWrapMode(QTextOption::NoWrap);
 
-    QTimer::singleShot(1, [=]() {
+    QTimer::singleShot(1, parent, [=]() {
         this->updateEditorGeometry(edit, option, index);
     });
 
-    connect(edit, &TextEdit::textChanged, [=]() {
+    connect(edit, &TextEdit::textChanged, this, [=]() {
         updateEditorGeometry(edit, option, index);
     });
 
-    connect(edit, &TextEdit::finishEditRequest, [=]() {
+    connect(edit, &TextEdit::finishEditRequest, this, [=]() {
         setModelData(edit, nullptr, index);
         edit->deleteLater();
     });
@@ -115,11 +186,18 @@ void ListViewDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
     auto cursor = edit->textCursor();
     cursor.setPosition(0, QTextCursor::MoveAnchor);
     cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
-    //qDebug()<<cursor.position();
-    if (edit->toPlainText().contains(".") && !edit->toPlainText().startsWith(".")) {
-        cursor.movePosition(QTextCursor::WordLeft, QTextCursor::KeepAnchor, 1);
-        cursor.movePosition(QTextCursor::Left, QTextCursor::KeepAnchor, 1);
-        //qDebug()<<cursor.position();
+    bool isDir = FileUtils::getFileIsFolder(index.data(Qt::UserRole).toString());
+    bool isDesktopFile = index.data(Qt::UserRole).toString().endsWith(".desktop");
+    bool isSoftLink = FileUtils::getFileIsSymbolicLink(index.data(Qt::UserRole).toString());
+    if (!isDesktopFile && !isSoftLink && !isDir && edit->toPlainText().contains(".") && !edit->toPlainText().startsWith(".")) {
+        int n = 1;
+        if(index.data(Qt::DisplayRole).toString().contains(".tar.")) //ex xxx.tar.gz xxx.tar.bz2
+            n = 2;
+        while(n){
+            cursor.movePosition(QTextCursor::WordLeft, QTextCursor::KeepAnchor, 1);
+            cursor.movePosition(QTextCursor::Left, QTextCursor::KeepAnchor, 1);
+            --n;
+        }
     }
     //qDebug()<<cursor.anchor();
     edit->setTextCursor(cursor);
@@ -142,13 +220,24 @@ void ListViewDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
     auto text = edit->toPlainText();
     if (text.isEmpty())
         return;
-    if (text == index.data(Qt::DisplayRole).toString())
-        return;
+
     //process special name . or .. or only space
     if (text == "." || text == ".." || text.trimmed() == "")
         return;
 
+    if (! index.isValid())
+        return;
+
     auto view = qobject_cast<DirectoryView::ListView *>(parent());
+    auto oldName = index.data(Qt::DisplayRole).toString();
+    if (text == oldName)
+    {
+        //create new file, should select the file or folder
+        auto flags = QItemSelectionModel::Select|QItemSelectionModel::Rows;
+        view->selectionModel()->select(index, flags);
+        view->setFocus();
+        return;
+    }
 
     auto fileOpMgr = FileOperationManager::getInstance();
     auto renameOp = new FileRenameOperation(index.data(FileItemModel::UriRole).toString(), text);
@@ -158,7 +247,9 @@ void ListViewDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
         auto uri = info->target();
         QTimer::singleShot(100, view, [=](){
             view->setSelections(QStringList()<<uri);
-            view->scrollToSelection(uri);
+            //after rename will nor sort immediately, comment to fix bug#60482
+            //view->scrollToSelection(uri);
+            view->setFocus();
         });
     }, Qt::BlockingQueuedConnection);
 
@@ -168,11 +259,9 @@ void ListViewDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 QSize ListViewDelegate::sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index ) const
 {
     QSize size = QStyledItemDelegate::sizeHint(option, index);
-    auto info = FileInfo::fromUri(index.data(Qt::UserRole).toString());
-    auto colors = info->getColors();
-    //fix color labels over 2 will overlap with item issue
-    if (colors.count() >2)
-        size.setHeight( size.height() + 20);
+    auto view = qobject_cast<DirectoryView::ListView *>(parent());
+    int expectedHeight = view->iconSize().height() + 4;
+    size.setHeight(qMax(expectedHeight, size.height()));
     return size;
 }
 
