@@ -45,22 +45,36 @@
 #include <QDragEnterEvent>
 #include <QMimeData>
 #include <QDragMoveEvent>
+#include <QDrag>
+#include <QPainter>
+#include <QWindow>
 
 #include <QApplication>
 #include <QStyleHints>
 
 #include <QDebug>
+#include <QToolTip>
+
+#include <QStyleOptionViewItem>
 
 using namespace Peony;
 using namespace Peony::DirectoryView;
 
 ListView::ListView(QWidget *parent) : QTreeView(parent)
 {
+    // use scroll per pixel mode for calculate vertical scroll bar range.
+    // see reUpdateScrollBar()
+    setVerticalScrollMode(ScrollPerPixel);
     setAttribute(Qt::WA_TranslucentBackground);
     setStyle(Peony::DirectoryView::ListViewStyle::getStyle());
 
+    setAutoScroll(true);
+    setAutoScrollMargin(100);
+
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
+    setSelectionBehavior(QTreeView::SelectRows);
+
     setAlternatingRowColors(true);
     setAutoFillBackground(true);
     setBackgroundRole(QPalette::Base);
@@ -85,18 +99,24 @@ ListView::ListView(QWidget *parent) : QTreeView(parent)
     m_renameTimer = new QTimer(this);
     m_renameTimer->setInterval(3000);
     m_editValid = false;
+
+    //use this property to fix bug 44314 and 33558
+    //bug#42244 need to find and fix update fail issue
+    setUniformRowHeights(true);
+    setIconSize(QSize(40, 40));
+    setMouseTracking(true);//追踪鼠标
+
+    m_rubberBand = new QRubberBand(QRubberBand::Shape::Rectangle, this);
 }
 
 void ListView::scrollTo(const QModelIndex &index, QAbstractItemView::ScrollHint hint)
 {
-    // NOTE:
-    // scrollTo() is confilcted with updateGeometry(), where it will
-    // leave a space for view. So I override this method. However,
-    // the fast keyboard locating of default tree view will be disabled
-    // due to the function is overrided, too.
-
-    //QTreeView::scrollTo(index, hint);
-    //updateGeometries();
+    // Note: due to we rewrite the calculation of view scroll area based on current process,
+    // we could not use QTreeView::scrollTo in some cases because it still based on old process
+    // and will conflict with new calculation.
+    Q_UNUSED(index)
+    Q_UNUSED(hint)
+    reUpdateScrollBar();
 }
 
 bool ListView::isDragging()
@@ -174,8 +194,30 @@ void ListView::bindModel(FileItemModel *sourceModel, FileItemProxyFilterSortMode
 void ListView::keyPressEvent(QKeyEvent *e)
 {
     QTreeView::keyPressEvent(e);
-    if (e->key() == Qt::Key_Control)
+    switch (e->key()) {
+    case Qt::Key_Control:
         m_ctrl_key_pressed = true;
+        break;
+    case Qt::Key_Up: {
+        if (!selectedIndexes().isEmpty()) {
+            QTreeView::scrollTo(selectedIndexes().first());
+        }
+        break;
+    }
+    case Qt::Key_Down: {
+        if (!selectedIndexes().isEmpty()) {
+            auto index = selectedIndexes().first();
+            if (index.row() + 1 == model()->rowCount()) {
+                verticalScrollBar()->setValue(qMin(verticalScrollBar()->value() + iconSize().height(), verticalScrollBar()->maximum()));
+            } else {
+                QTreeView::scrollTo(selectedIndexes().first());
+            }
+        }
+        break;
+    }
+    default:
+        break;
+    }
 }
 
 void ListView::keyReleaseEvent(QKeyEvent *e)
@@ -193,9 +235,14 @@ void ListView::mousePressEvent(QMouseEvent *e)
                 return;
         }
         Q_EMIT customContextMenuRequested(e->pos());
+        m_rubberBand->hide();
         return;
     }
 
+    m_isLeftButtonPressed = true;
+    m_rubberBand->hide();
+    m_lastPressedLogicPoint = e->pos() + QPoint(horizontalOffset(), verticalOffset());
+
     auto index = indexAt(e->pos());
     bool isIndexSelected = selectedIndexes().contains(index);
 
@@ -261,9 +308,41 @@ void ListView::mousePressEvent(QMouseEvent *e)
 void ListView::mouseReleaseEvent(QMouseEvent *e)
 {
     QTreeView::mouseReleaseEvent(e);
+    m_rubberBand->hide();
+    m_isLeftButtonPressed = false;
+}
 
-    if (e->button() != Qt::LeftButton) {
-        return;
+void ListView::mouseMoveEvent(QMouseEvent *e)
+{
+    QModelIndex itemIndex = indexAt(e->pos());
+    if (!itemIndex.isValid()) {
+        if (QToolTip::isVisible()) {
+             QToolTip::hideText();
+         }
+    } else {
+        if (0 != itemIndex.column() && QToolTip::isVisible()) {
+            QToolTip::hideText();
+        }
+    }
+
+    QTreeView::mouseMoveEvent(e);
+
+    if (e->buttons() & Qt::LeftButton) {
+        auto pos = e->pos();
+        auto offset = QPoint(horizontalOffset(), verticalOffset());
+        auto logicPos = pos + offset;
+        QRect logicRect = QRect(logicPos, m_lastPressedLogicPoint);
+        m_logicRect = logicRect.normalized();
+
+        int dx = -horizontalOffset();
+        int dy = -verticalOffset() + this->header()->height();
+        auto realRect = m_logicRect.adjusted(dx, dy, dx ,dy);
+
+        if (!m_rubberBand->isVisible())
+            m_rubberBand->show();
+        m_rubberBand->setGeometry(realRect);
+    } else {
+        m_rubberBand->hide();
     }
 }
 
@@ -279,7 +358,7 @@ void ListView::dragEnterEvent(QDragEnterEvent *e)
     m_editValid = false;
     qDebug()<<"dragEnterEvent()";
     //QTreeView::dragEnterEvent(e);
-    if (e->keyboardModifiers() && Qt::ControlModifier)
+    if (e->keyboardModifiers() & Qt::ControlModifier)
         m_ctrl_key_pressed = true;
     else
         m_ctrl_key_pressed = false;
@@ -294,13 +373,13 @@ void ListView::dragEnterEvent(QDragEnterEvent *e)
 
 void ListView::dragMoveEvent(QDragMoveEvent *e)
 {
-    if (e->keyboardModifiers() && Qt::ControlModifier)
+    if (e->keyboardModifiers() & Qt::ControlModifier)
         m_ctrl_key_pressed = true;
     else
         m_ctrl_key_pressed = false;
 
     auto action = m_ctrl_key_pressed ? Qt::CopyAction : Qt::MoveAction;
-    qDebug()<<"list view dragMoveEvent()" <<action <<m_ctrl_key_pressed;
+    //qDebug()<<"list view dragMoveEvent()" <<action <<m_ctrl_key_pressed;
     auto index = indexAt(e->pos());
     if (index.isValid() && index != m_last_index) {
         QHoverEvent he(QHoverEvent::HoverMove, e->posF(), e->posF());
@@ -325,6 +404,13 @@ void ListView::dropEvent(QDropEvent *e)
         case QAbstractItemView::DropIndicatorPosition::OnItem: {
             break;
         }
+        case QAbstractItemView::DropIndicatorPosition::OnViewport: {
+            if (e->keyboardModifiers() & Qt::ControlModifier) {
+                break;
+            } else {
+                return;
+            }
+        }
         default:
             return;
         }
@@ -333,13 +419,17 @@ void ListView::dropEvent(QDropEvent *e)
 
     m_last_index = QModelIndex();
     //m_edit_trigger_timer.stop();
-    if (e->keyboardModifiers() && Qt::ControlModifier)
+    if (e->keyboardModifiers() & Qt::ControlModifier)
         m_ctrl_key_pressed = true;
     else
         m_ctrl_key_pressed = false;
 
     auto action = m_ctrl_key_pressed ? Qt::CopyAction : Qt::MoveAction;
     e->setDropAction(action);
+    if (e->keyboardModifiers() & Qt::ShiftModifier) {
+        action = Qt::TargetMoveAction;
+    }
+
     auto proxy_index = indexAt(e->pos());
     auto index = m_proxy_model->mapToSource(proxy_index);
     qDebug()<<"dropEvent" <<action <<m_ctrl_key_pressed <<indexAt(e->pos()).isValid();
@@ -347,7 +437,15 @@ void ListView::dropEvent(QDropEvent *e)
     if (e->source() == this)
     {
         if (indexAt(e->pos()).isValid())
-            m_model->dropMimeData(e->mimeData(), action, 0, 0, index);
+        {
+            auto uri = m_proxy_model->itemFromIndex(proxy_index)->uri();
+            if(!e->mimeData()->urls().contains(uri))
+                m_model->dropMimeData(e->mimeData(), action, 0, 0, index);
+        } else {
+            if (m_ctrl_key_pressed) {
+                m_model->dropMimeData(e->mimeData(), Qt::CopyAction, 0, 0, QModelIndex());
+            }
+        }
         return;
     }
 
@@ -363,21 +461,44 @@ void ListView::resizeEvent(QResizeEvent *e)
     }
 }
 
-void ListView::updateGeometries()
+/*!
+ * \brief ListView::reUpdateScrollBar
+ * \details
+ * tree view use QTreeViewPrivate::updateScrollBars() for reset scrollbar range.
+ * there are 3 parts for that method called.
+ *
+ * 1. QTreeView::scrollTo()
+ * 2. QTreeView::dataChanged()
+ * 3. QTreeView::updateGeometries()
+ *
+ * we have to override all of them to make sure that our custom scrollbar range
+ * set correctly.
+ */
+void ListView::reUpdateScrollBar()
 {
-    QTreeView::updateGeometries();
     if (!model())
         return;
 
-    if (model()->columnCount() == 0 || model()->rowCount() == 0)
+    if (model()->rowCount() == 0) {
         return;
+    }
 
-    header()->setFixedWidth(this->width());
+    int totalHeight = 0;
+    int rowCount = model()->rowCount();
+    for (int row = 0; row < rowCount; row++) {
+        auto index = model()->index(row, 0);
+        totalHeight += sizeHintForIndex(index).height();
+    }
 
-    QStyleOptionViewItem opt = viewOptions();
-    int height = itemDelegate()->sizeHint(opt, QModelIndex()).height();
-    verticalScrollBar()->setMaximum(verticalScrollBar()->maximum() + 2);
-    //setViewportMargins(0, header()->height(), 0, height);
+    verticalScrollBar()->setSingleStep(iconSize().height());
+    verticalScrollBar()->setPageStep(viewport()->height() - header()->height());
+    verticalScrollBar()->setRange(0, totalHeight + header()->height() + 100 - viewport()->height());
+}
+
+void ListView::updateGeometries()
+{
+    QTreeView::updateGeometries();
+    reUpdateScrollBar();
 }
 
 void ListView::wheelEvent(QWheelEvent *e)
@@ -389,10 +510,85 @@ void ListView::wheelEvent(QWheelEvent *e)
     QTreeView::wheelEvent(e);
 }
 
+void ListView::focusInEvent(QFocusEvent *e)
+{
+    QTreeView::focusInEvent(e);
+    if (e->reason() == Qt::TabFocus) {
+        if (selectedIndexes().isEmpty()) {
+            selectionModel()->select(model()->index(0, 0), QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
+        } else {
+            QTreeView::scrollTo(selectedIndexes().first(), QTreeView::EnsureVisible);
+            reUpdateScrollBar();
+            auto selections = selectedIndexes();
+            clearSelection();
+            QTimer::singleShot(100, this, [=](){
+                for (auto index : selections) {
+                    selectionModel()->select(index, QItemSelectionModel::Select);
+                }
+            });
+        }
+    }
+}
+
+void ListView::startDrag(Qt::DropActions flags)
+{
+    auto indexes = selectedIndexes();
+    if (indexes.count() > 0) {
+        auto pos = mapFromGlobal(QCursor::pos());
+        qreal scale = 1.0;
+        QWidget *window = this->window();
+        if (window) {
+            auto windowHandle = window->windowHandle();
+            if (windowHandle) {
+                scale = windowHandle->devicePixelRatio();
+            }
+        }
+
+        auto drag = new QDrag(this);
+        drag->setMimeData(model()->mimeData(indexes));
+
+        QRegion rect;
+        QHash<QModelIndex, QRect> indexRectHash;
+        for (auto index : indexes) {
+            rect += (visualRect(index));
+            indexRectHash.insert(index, visualRect(index));
+        }
+
+        QRect realRect = rect.boundingRect();
+        QPixmap pixmap(realRect.size() * scale);
+        pixmap.fill(Qt::transparent);
+        pixmap.setDevicePixelRatio(scale);
+        QPainter painter(&pixmap);
+        for (auto index : indexes) {
+            painter.save();
+            painter.translate(indexRectHash.value(index).topLeft() - rect.boundingRect().topLeft());
+            //painter.translate(-rect.boundingRect().topLeft());
+            QStyleOptionViewItem opt = viewOptions();
+            auto viewItemDelegate = static_cast<ListViewDelegate *>(itemDelegate());
+            viewItemDelegate->initIndexOption(&opt, index);
+            opt.displayAlignment = Qt::Alignment(Qt::AlignLeft|Qt::AlignVCenter);
+            opt.rect.setSize(indexRectHash.value(index).size());
+            opt.rect.moveTo(0, 0);
+            opt.state |= QStyle::State_Selected;
+            painter.setOpacity(0.8);
+            QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &opt, &painter);
+            painter.restore();
+        }
+
+        drag->setPixmap(pixmap);
+        drag->setHotSpot(pos - rect.boundingRect().topLeft() - QPoint(0, header()->height()));
+        drag->setDragCursor(QPixmap(), m_ctrl_key_pressed? Qt::CopyAction: Qt::MoveAction);
+        drag->exec(m_ctrl_key_pressed? Qt::CopyAction: Qt::MoveAction);
+    }
+}
+
 void ListView::slotRename()
 {
-    //trash path not allow rename
-    if (getDirectoryUri().startsWith("trash://"))
+    //special path like trash path not allow rename
+    if (getDirectoryUri().startsWith("trash://")
+        || getDirectoryUri().startsWith("recent://")
+        || getDirectoryUri().startsWith("favorite://")
+        || getDirectoryUri().startsWith("search://"))
         return;
 
     //standardPaths not allow rename
@@ -403,7 +599,7 @@ void ListView::slotRename()
 
     //delay edit action to avoid doubleClick or dragEvent
     qDebug()<<"slotRename"<<m_editValid;
-    QTimer::singleShot(300, m_renameTimer, [&]() {
+    QTimer::singleShot(300, this, [&]() {
         qDebug()<<"singleshot"<<m_editValid;
         if(m_editValid) {
             m_renameTimer->stop();
@@ -450,12 +646,25 @@ void ListView::adjustColumnsSize()
     if(columnWidth(0) < columnWidth(1))
         setColumnWidth(0, columnWidth(1));
 
-    if (this->width() - rightPartsSize < BOTTOM_STATUS_MARGIN)
+    if (this->width() - rightPartsSize < BOTTOM_STATUS_MARGIN) {
+        int size = width() - BOTTOM_STATUS_MARGIN;
+        size /= header()->count() - 1;
+        setColumnWidth(0, BOTTOM_STATUS_MARGIN);
+        for (int column = 1; column < model()->columnCount(); column++) {
+            setColumnWidth(column, size);
+        }
         return;
+    }
 
     header()->resizeSection(0, this->viewport()->width() - rightPartsSize);
 }
 
+void ListView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles)
+{
+    QTreeView::dataChanged(topLeft, bottomRight, roles);
+    reUpdateScrollBar();
+}
+
 DirectoryViewProxyIface *ListView::getProxy()
 {
     return m_proxy;
@@ -489,13 +698,16 @@ const QStringList ListView::getSelections()
 void ListView::setSelections(const QStringList &uris)
 {
     clearSelection();
+    QItemSelection selection;
     for (auto uri: uris) {
         const QModelIndex index = m_proxy_model->indexFromUri(uri);
         if (index.isValid()) {
-            auto flags = QItemSelectionModel::Select|QItemSelectionModel::Rows;
-            selectionModel()->select(index, flags);
+            QItemSelection selectionToBeMerged(index, index);
+            selection.merge(selectionToBeMerged, QItemSelectionModel::Select);
         }
     }
+    auto flags = QItemSelectionModel::Select|QItemSelectionModel::Rows;
+    selectionModel()->select(selection, flags);
 }
 
 const QStringList ListView::getAllFileUris()
@@ -510,6 +722,7 @@ QRect ListView::visualRect(const QModelIndex &index) const
 //    if (index.column() == 0) {
 //        rect.setX(0);
 //    }
+
     return rect;
 }
 
@@ -521,6 +734,7 @@ void ListView::open(const QStringList &uris, bool newWindow)
 void ListView::beginLocationChange()
 {
     m_editValid = false;
+    m_last_index = QModelIndex();
     //setModel(nullptr);
     m_model->setRootUri(m_current_uri);
 }
@@ -547,6 +761,7 @@ void ListView::scrollToSelection(const QString &uri)
 {
     auto index = m_proxy_model->indexFromUri(uri);
     QTreeView::scrollTo(index);
+    reUpdateScrollBar();
 }
 
 void ListView::setCutFiles(const QStringList &uris)
@@ -562,6 +777,8 @@ int ListView::getSortType()
 
 void ListView::setSortType(int sortType)
 {
+    //fix indicator not agree with actual sort order issue, link to bug#71475
+    header()->setSortIndicator(sortType, Qt::SortOrder(getSortOrder()));
     m_proxy_model->sort(sortType, Qt::SortOrder(getSortOrder()));
 }
 
@@ -572,6 +789,8 @@ int ListView::getSortOrder()
 
 void ListView::setSortOrder(int sortOrder)
 {
+    //fix indicator not agree with actual sort order issue, link to bug#71475
+    header()->setSortIndicator(getSortType(), Qt::SortOrder(sortOrder));
     m_proxy_model->sort(getSortType(), Qt::SortOrder(sortOrder));
 }
 
@@ -580,7 +799,8 @@ void ListView::editUri(const QString &uri)
     setState(QTreeView::NoState);
     auto origin = FileUtils::getOriginalUri(uri);
     setIndexWidget(m_proxy_model->indexFromUri(origin), nullptr);
-    QTreeView::scrollTo(m_proxy_model->indexFromUri(origin));
+    //注释该行以修复bug:#60474
+//    QTreeView::scrollTo(m_proxy_model->indexFromUri(origin));
     edit(m_proxy_model->indexFromUri(origin));
 }
 
@@ -590,6 +810,31 @@ void ListView::editUris(const QStringList uris)
     //implement batch rename.
 }
 
+void ListView::keyboardSearch(const QString &key)
+{
+    // ensure current index is index in display name column
+    if (currentIndex().column() != 0) {
+        selectionModel()->setCurrentIndex(m_model->index(currentIndex().row(), 0, currentIndex().parent()), QItemSelectionModel::SelectCurrent);
+    }
+
+    // note: checking qtreeview.cpp we can find that the keyboard search only select rows
+    // while selection mode is single selection. so we have a trick here for trigger that
+    // action.
+    setSelectionMode(QTreeView::SingleSelection);
+    QAbstractItemView::keyboardSearch(key);
+    setSelectionMode(QTreeView::ExtendedSelection);
+
+    auto indexes = selectedIndexes();
+    if (!indexes.isEmpty()) {
+        QTreeView::scrollTo(indexes.first(), QTreeView::PositionAtCenter);
+        reUpdateScrollBar();
+        if (verticalScrollBar()->value() < viewport()->height()) {
+            return;
+        }
+        verticalScrollBar()->setValue(qMin(verticalScrollBar()->value() + iconSize().height(), verticalScrollBar()->maximum()));
+    }
+}
+
 //List View 2
 ListView2::ListView2(QWidget *parent) : DirectoryViewWidget(parent)
 {
@@ -625,13 +870,16 @@ void ListView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *pr
     m_view->bindModel(model, proxyModel);
     connect(m_model, &FileItemModel::selectRequest, this, &DirectoryViewWidget::updateWindowSelectionRequest);
     connect(model, &FileItemModel::findChildrenFinished, this, &DirectoryViewWidget::viewDirectoryChanged);
-    connect(m_model, &FileItemModel::updated, m_view, &ListView::resort);
+    //connect(m_model, &FileItemModel::updated, m_view, &ListView::resort);
 
     connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged,
             this, &DirectoryViewWidget::viewSelectionChanged);
 
     connect(m_view, &ListView::activated, this, [=](const QModelIndex &index) {
-        auto uri = index.data(Qt::UserRole).toString();
+        //when selections is more than 1, let mainwindow to process
+        if (getSelections().count() != 1)
+            return;
+        auto uri = getSelections().first();
         Q_EMIT this->viewDoubleClicked(uri);
     });
 
@@ -684,10 +932,17 @@ void ListView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *pr
     });
 }
 
+void ListView2::repaintView()
+{
+    m_view->update();
+    m_view->viewport()->update();
+}
+
 void ListView2::setCurrentZoomLevel(int zoomLevel)
 {
     int base = 16;
     int adjusted = base + zoomLevel;
+
     m_view->setIconSize(QSize(adjusted, adjusted));
     m_zoom_level = zoomLevel;
 }
