@@ -75,10 +75,18 @@ private:
     QStringList m_selections;
 
     bool m_is_cd = false;
+    bool m_is_ftp = false;
     bool m_is_computer = false;
+    bool m_is_network = false;
     bool m_is_trash = false;
     bool m_is_search = false;
     bool m_is_recent = false;
+    bool m_is_favorite = false;
+    bool m_can_delete = true;           // if contains computer:/// trash:/// recent:/// and desktop path
+    bool m_is_kydroid = false;
+    bool m_is_filesafe = false;
+    bool m_is_filebox_file = false;     //filesafe path files operation flag
+    bool m_is_smb_file = false;
 
     const int ELIDE_TEXT_LENGTH = 16;
 
