@@ -42,10 +42,9 @@ AdvancedLocationBar::AdvancedLocationBar(QWidget *parent) : QWidget(parent)
     m_bar = new Peony::LocationBar(this);
     m_edit = new Peony::PathEdit(this);
     m_search_bar = new Peony::SearchBarContainer(this);
-    //bar->connect(bar, &Peony::LocationBar::groupChangedRequest, bar, &Peony::LocationBar::setRootUri);
     m_bar->connect(m_bar, &Peony::LocationBar::blankClicked, [=]() {
         auto curUri = m_bar->getCurentUri();
-        if (! curUri.startsWith("trash:///"))
+        if (! curUri.startsWith("trash:///") && ! curUri.startsWith("recent:///"))
         {
             layout->setCurrentWidget(m_edit);
             m_edit->setFocus();
@@ -54,13 +53,16 @@ AdvancedLocationBar::AdvancedLocationBar(QWidget *parent) : QWidget(parent)
     });
 
     m_edit->connect(m_edit, &Peony::PathEdit::uriChangeRequest, [=](const QString uri) {
-        if (m_text == uri) {
-            Q_EMIT this->refreshRequest();
-            return;
+        //qDebug() << "uriChangeRequest:" <<uri;
+        QString targetUri = uri;
+        //fix bug 38942
+        while (targetUri.endsWith("/") && targetUri != "file:///")
+        {
+            targetUri = targetUri.left(targetUri.lastIndexOf("/"));
         }
-        m_bar->setRootUri(uri);
+        m_bar->setRootUri(targetUri);
         layout->setCurrentWidget(m_bar);
-        Q_EMIT this->updateWindowLocationRequest(uri);
+        Q_EMIT this->updateWindowLocationRequest(targetUri);
         m_text = m_edit->text();
         if (! m_text.startsWith("search://"))
             m_last_non_search_path = m_text;
@@ -83,9 +85,10 @@ AdvancedLocationBar::AdvancedLocationBar(QWidget *parent) : QWidget(parent)
 
     m_search_bar->connect(m_search_bar, &Peony::SearchBarContainer::returnPressed, [=]() {
         auto key = m_search_bar->text();
+        key = processSpecialChar(key);
+        qDebug() << "search key:" <<key <<m_last_key;
         if (key != m_last_key)
         {
-            qDebug() << "start search" << key;
             Q_EMIT searchRequest(m_last_non_search_path, key);
             m_last_key = key;
         }
@@ -105,9 +108,27 @@ AdvancedLocationBar::AdvancedLocationBar(QWidget *parent) : QWidget(parent)
     setFixedHeight(m_edit->height());
 }
 
+QString AdvancedLocationBar::processSpecialChar(QString key)
+{
+    if (key.length() == 0)
+        return key;
+    //qDebug() << "enter processSpecialChar:" <<key;
+    for(auto mchar : SPECIAL_CHARS)
+    {
+        if (key.contains(mchar))
+        {
+            QString tmp = mchar;
+            tmp.replace("\\", "");
+            key = key.replace(tmp, "\\" + mchar);
+        }
+    }
+
+    //qDebug() << "ret processSpecialChar:" <<key;
+    return key;
+}
+
 void AdvancedLocationBar::updateLocation(const QString &uri)
 {
-    //qDebug() << "AdvancedLocationBar updateLocation:"<<uri;
     m_bar->setRootUri(uri);
     m_edit->setUri(uri);
     m_text = uri;
@@ -129,6 +150,11 @@ void AdvancedLocationBar::startEdit()
     m_edit->setUri(m_bar->getCurentUri());
 }
 
+void AdvancedLocationBar::cancelEdit()
+{
+    m_edit->cancelList();
+}
+
 void AdvancedLocationBar::finishEdit()
 {
     Q_EMIT m_edit->returnPressed();
@@ -142,13 +168,23 @@ void AdvancedLocationBar::switchEditMode(bool bSearchMode)
         m_layout->setCurrentWidget(m_search_bar);
         m_search_bar->setPlaceholderText(tr("Search Content..."));
         m_search_bar->setFocus();
+        m_in_search_mode = true;
     }
-    else
+    else if(m_in_search_mode)
     {
         //quit search mode, show non search contents
-        m_search_bar->setText("");
-        Q_EMIT this->updateWindowLocationRequest(m_last_non_search_path, false);
+        if (m_last_key.length() > 0)
+        {
+            Q_EMIT this->updateWindowLocationRequest(m_last_non_search_path, false);
+        }
+
+        //在文件保护箱中搜索时，清空搜索内容会导致刷新，路径更新需要授权，导致2次弹框
+        //屏蔽清空搜索内容代码，解决bug#76431, 概率性闪退问题
+        QString curUri = m_bar->getCurentUri();
+        if (! curUri.startsWith("filesafe:///"))
+            m_search_bar->setText("");
         m_layout->setCurrentWidget(m_bar);
+        m_in_search_mode = false;
     }
 }
 
