@@ -50,9 +50,11 @@ Q_SIGNALS:
 public Q_SLOTS:
     void updateLocation(const QString &uri);
     void startEdit();
+    void cancelEdit();
     void finishEdit();
     void switchEditMode(bool bSearchMode);
     void clearSearchBox();
+    QString processSpecialChar(QString key);
 
 private:
     QStackedLayout *m_layout;
@@ -64,6 +66,10 @@ private:
     QString m_text;
     QString m_last_non_search_path;
     QString m_last_key = "";
+
+    bool m_in_search_mode = false;
+
+    const QStringList SPECIAL_CHARS = {"\$", "\|", "\^", "\*"};
 };
 
 }
