@@ -1,4 +1,4 @@
-/*
+﻿/*
  * Peony-Qt's Library
  *
  * Copyright (C) 2020, KylinSoft Co., Ltd.
@@ -46,6 +46,7 @@
 #include <QImageReader>
 
 #include <QPainter>
+#include <QGSettings>
 
 #include "icon-container.h"
 
@@ -59,8 +60,12 @@
 
 using namespace Peony;
 
+#define LABEL_MAX_WIDTH       165
+
 DefaultPreviewPage::DefaultPreviewPage(QWidget *parent) : QStackedWidget (parent)
 {
+    setContentsMargins(10, 20, 10, 20);
+
     auto label = new QLabel(tr("Select the file you want to preview..."), this);
     label->setWordWrap(true);
     label->setAlignment(Qt::AlignCenter);
@@ -79,6 +84,19 @@ DefaultPreviewPage::DefaultPreviewPage(QWidget *parent) : QStackedWidget (parent
     addWidget(m_empty_tab_widget);
 
     setCurrentWidget(m_empty_tab_widget);
+
+    if (QGSettings::isSchemaInstalled("org.ukui.style")) {
+        QGSettings *gSetting = new QGSettings("org.ukui.style", QByteArray(), this);
+        connect(gSetting, &QGSettings::changed, this, [=](const QString &key) {
+            if ("systemFontSize" == key) {
+                if (m_support && m_preview_tab_widget) {
+                    if (m_info) {
+                        m_preview_tab_widget->updateInfo(m_info.get());
+                    }
+                }
+            }
+        });
+    }
 }
 
 DefaultPreviewPage::~DefaultPreviewPage()
@@ -92,9 +110,10 @@ bool DefaultPreviewPage::eventFilter(QObject *obj, QEvent *ev)
         if (ev->type() == QEvent::Resize) {
             auto e = static_cast<QResizeEvent*>(ev);
             auto page = qobject_cast<FilePreviewPage*>(m_preview_tab_widget);
-            int width = e->size().width()/3;
-            width = width>96? width: 96;
-            page->resizeIcon(QSize(width, width));
+            int width = e->size().width() - 50;
+            width = qMax(width, 96);
+            width = qMin(width, 256);
+            page->resizeIcon(QSize(width, width * 2/3));
         }
     }
     return QStackedWidget::eventFilter(obj, ev);
@@ -164,29 +183,42 @@ FilePreviewPage::FilePreviewPage(QWidget *parent) : QFrame(parent)
     m_layout->addWidget(m_icon);
 
     m_form = new QFormLayout(this);
+    m_form->setSpacing(3);
+
     m_display_name_label = new QLabel(this);
-    m_display_name_label->setWordWrap(true);
-    m_form->addRow(tr("File Name:"), m_display_name_label);
+    QLabel *file_name_label = new QLabel(this);
+    file_name_label->setAlignment(Qt::AlignTop);
+    file_name_label->setText(tr("File Name:"));
+    m_form->addRow(file_name_label, m_display_name_label);
+
     m_type_label = new QLabel(this);
     m_form->addRow(tr("File Type:"), m_type_label);
+
     m_time_access_label = new QLabel(this);
     m_form->addRow(tr("Time Access:"), m_time_access_label);
+
     m_time_modified_label = new QLabel(this);
     m_form->addRow(tr("Time Modified:"), m_time_modified_label);
+
     m_file_count_label = new QLabel(this);
-    m_form->addRow(tr("Children Count:"), m_file_count_label);
+    QLabel *children_label = new QLabel(this);
+    children_label->setAlignment(Qt::AlignTop);
+    children_label->setText(tr("Children Count:"));
+    m_form->addRow(children_label, m_file_count_label);
+
     m_total_size_label = new QLabel(this);
     m_form->addRow(tr("Size:"), m_total_size_label);
 
     //image
     m_image_size = new QLabel(this);
-    m_form->addRow(tr("Image size:"), m_image_size);
+    m_form->addRow(tr("Image resolution:"), m_image_size);
+
     m_image_format = new QLabel(this);
-    m_form->addRow(tr("Image format:"), m_image_format);
+    m_form->addRow(tr("color model:"), m_image_format);
 
     m_form->setFieldGrowthPolicy(QFormLayout::FieldsStayAtSizeHint);
     m_form->setFormAlignment(Qt::AlignHCenter);
-    m_form->setLabelAlignment(Qt::AlignRight);
+    m_form->setLabelAlignment(Qt::AlignLeft);
 
     QWidget *form = new QWidget(this);
     form->setLayout(m_form);
@@ -198,6 +230,30 @@ FilePreviewPage::~FilePreviewPage()
 
 }
 
+void FilePreviewPage::wrapData(QLabel *p_label, const QString &text)
+{
+    QString wrapText = text;
+    QFontMetrics fontMetrics = p_label->fontMetrics();
+    int textSize = fontMetrics.width(wrapText);
+
+    if(textSize > LABEL_MAX_WIDTH){
+        int lastIndex = 0;
+        for(int i = lastIndex; i < wrapText.length(); i++) {
+            if(fontMetrics.width(wrapText.mid(lastIndex, i - lastIndex)) == LABEL_MAX_WIDTH) {
+                lastIndex = i;
+                wrapText.insert(i, '\n');
+            } else if(fontMetrics.width(wrapText.mid(lastIndex, i - lastIndex)) > LABEL_MAX_WIDTH) {
+                lastIndex = i;
+                wrapText.insert(i - 1, '\n');
+            } else {
+                continue;
+            }
+        }
+    }
+
+    p_label->setText(wrapText);
+}
+
 void FilePreviewPage::updateInfo(FileInfo *info)
 {
     if (info->displayName().isEmpty()) {
@@ -211,23 +267,15 @@ void FilePreviewPage::updateInfo(FileInfo *info)
     }
     auto icon = QIcon::fromTheme(info->iconName(), QIcon::fromTheme("text-x-generic"));
     m_icon->setIcon(thumbnail.isNull()? icon: thumbnail);
-    //m_icon->setIcon(info->thumbnail().isNull()? QIcon::fromTheme(info->iconName()): info->thumbnail());
-    m_display_name_label->setText(info->displayName());
-    m_type_label->setText(info->fileType());
+    wrapData(m_display_name_label, info->displayName());
+
+    wrapData(m_type_label, info->fileType());
 
-    QLocale locale;
     auto access = QDateTime::fromMSecsSinceEpoch(info->accessTime()*1000);
     auto modify = QDateTime::fromMSecsSinceEpoch(info->modifiedTime()*1000);
-    if (locale.language() == QLocale::Chinese)
-    {
-        m_time_access_label->setText(access.toString(Qt::SystemLocaleShortDate));
-        m_time_modified_label->setText(modify.toString(Qt::SystemLocaleShortDate));
-    }
-    else
-    {
-        m_time_access_label->setText(access.toString(Qt::ISODate));
-        m_time_modified_label->setText(modify.toString(Qt::ISODate));
-    }
+
+    wrapData(m_time_access_label, access.toString(Qt::SystemLocaleShortDate));
+    wrapData(m_time_modified_label, modify.toString(Qt::SystemLocaleShortDate));
 
     m_file_count_label->setText(tr(""));
     if (info->isDir()) {
@@ -267,7 +315,11 @@ void FilePreviewPage::updateInfo(FileInfo *info)
 
     }
 
-    countAsync(info->uri());
+    if (info->isSymbolLink()&&!info->symlinkTarget().isEmpty()){
+        countAsync("file:///" + info->symlinkTarget());
+    } else {
+        countAsync(info->uri());
+    }
 }
 
 void FilePreviewPage::countAsync(const QString &uri)
@@ -279,6 +331,7 @@ void FilePreviewPage::countAsync(const QString &uri)
 
     QStringList uris;
     uris<<uri;
+    //FIXME: replace BLOCKING api in ui thread.
     auto info = FileInfo::fromUri(uri);
     m_count_op = new FileCountOperation(uris, !info->isDir());
     connect(m_count_op, &FileOperation::operationStarted, this, &FilePreviewPage::resetCount, Qt::BlockingQueuedConnection);
@@ -289,9 +342,18 @@ void FilePreviewPage::countAsync(const QString &uri)
 
 void FilePreviewPage::updateCount()
 {
-    m_file_count_label->setText(tr("%1 total, %2 hidden").arg(m_file_count).arg(m_hidden_count));
-    auto format = g_format_size(m_total_size);
-    m_total_size_label->setText(format);
+    wrapData(m_file_count_label, tr("%1 total, %2 hidden").arg(m_file_count).arg(m_hidden_count));
+
+    auto format = g_format_size_full(m_total_size,G_FORMAT_SIZE_IEC_UNITS);
+    QString fileSize(format);
+    if (fileSize.contains("KiB")) {
+        fileSize.replace("KiB", "KB");
+    } else if (fileSize.contains("MiB")) {
+        fileSize.replace("MiB", "MB");
+    } else if (fileSize.contains("GiB")) {
+        fileSize.replace("GiB", "GB");
+    }
+    m_total_size_label->setText(fileSize);
     g_free(format);
 }
 
