@@ -191,11 +191,16 @@ FileOperation *FileOperationUtils::moveWithAction(const QStringList &srcUris, co
             destDir = destUri;
         }
 
-        auto moveOp = new FileMoveOperation(srcUris, destDir);
-        moveOp->setAction(action);
+        if (action == Qt::CopyAction) {
+            // fix 71411
+            op = new FileCopyOperation(srcUris, destDir);
+        } else {
+            auto moveOp = new FileMoveOperation(srcUris, destDir);
+            moveOp->setAction(action);
+            op = moveOp;
+        }
 
-        op = moveOp;
-        fileOpMgr->startOperation(moveOp, addHistory);
+        fileOpMgr->startOperation(op, addHistory);
     } else {
         op = FileOperationUtils::trash(srcUris, true);
     }
@@ -269,7 +274,6 @@ static int getNumOfFileName(const QString &name)
         while ((pos = regExp.indexIn(name, pos)) != -1) {
             tmp = regExp.cap(0).toUtf8();
             pos += regExp.matchedLength();
-            qDebug()<<"pos"<<pos;
         }
         tmp.remove(0,1);
         tmp.chop(1);
