@@ -356,8 +356,10 @@ void FileInfoJob::refreshInfoContents(GFileInfo *new_info)
     }
 
     if (info->m_size) {
-        char *size_full = strtok(g_format_size_full(info->m_size, G_FORMAT_SIZE_IEC_UNITS),"iB");
-        info->m_file_size = size_full;
+//        char *size_full = strtok(g_format_size_full(info->m_size, G_FORMAT_SIZE_IEC_UNITS),"iB");
+        //列表视图显示改为GB - List view display changed to GB
+        char *size_full = g_format_size_full(info->m_size, G_FORMAT_SIZE_IEC_UNITS);
+        info->m_file_size = QString(size_full).replace("iB", "B");;
         g_free(size_full);
     } else {
         info->m_file_size = nullptr;
@@ -382,9 +384,10 @@ void FileInfoJob::refreshInfoContents(GFileInfo *new_info)
     {
        QString deletionDate = g_file_info_get_attribute_as_string(new_info, G_FILE_ATTRIBUTE_TRASH_DELETION_DATE);
        info->m_deletion_date = deletionDate.replace("T", " ");
-       auto date = g_file_info_get_deletion_date(new_info);
-       info->m_deletion_date_uint64 = g_date_time_to_unix(date);
-       g_date_time_unref(date);
+
+       QDateTime dateTime = QDateTime::fromString (deletionDate, "yyyy-MM-dd HH:mm:ss");
+
+       info->m_deletion_date_uint64 = dateTime.toMSecsSinceEpoch ();
     }
 
     m_info->m_meta_info = FileMetaInfo::fromGFileInfo(m_info->uri(), new_info);
