@@ -22,16 +22,19 @@
 
 #include "file-info-manager.h"
 #include "thumbnail-manager.h"
+#include <QMap>
 #include <QDebug>
 
 using namespace Peony;
 
 static FileInfoManager* global_file_info_manager = nullptr;
-static QHash<QString, std::shared_ptr<FileInfo>> *global_info_list = nullptr;
+static QMap<QString, std::weak_ptr<FileInfo>> *global_info_list = nullptr;
+
+static QMutex m_op_lock;
 
 FileInfoManager::FileInfoManager()
 {
-    global_info_list = new QHash<QString, std::shared_ptr<FileInfo>>();
+    global_info_list = new QMap<QString, std::weak_ptr<FileInfo>>();
 }
 
 FileInfoManager::~FileInfoManager()
@@ -46,51 +49,33 @@ FileInfoManager *FileInfoManager::getInstance()
     return global_file_info_manager;
 }
 
-std::shared_ptr<FileInfo> FileInfoManager::findFileInfoByUri(QString uri)
+std::shared_ptr<FileInfo> FileInfoManager::findFileInfoByUri(const QString &uri)
 {
     Q_ASSERT(global_info_list);
-    return global_info_list->value(uri);//.lock();
+    m_op_lock.lock();
+    auto info = global_info_list->value(uri).lock();//.lock();
+    m_op_lock.unlock();
+    return info;
 }
 
 std::shared_ptr<FileInfo> FileInfoManager::insertFileInfo(std::shared_ptr<FileInfo> info)
 {
     Q_ASSERT(global_info_list);
 
-    if (global_info_list->value(info->uri())) {
+    m_op_lock.lock();
+
+    if (global_info_list->value(info->uri()).lock()) {
         //qDebug()<<"has info yet"<<info->uri();
-        info = global_info_list->value(info->uri());
+        info = global_info_list->value(info->uri()).lock();
     } else {
         global_info_list->insert(info->uri(), info);
     }
 
+    m_op_lock.unlock();
+
     return info;
 }
 
-void FileInfoManager::removeFileInfobyUri(QString uri)
-{
-    Q_ASSERT(global_info_list);
-    global_info_list->remove(uri);
-}
-
-void FileInfoManager::clear()
-{
-    Q_ASSERT(global_info_list);
-    global_info_list->clear();
-}
-
-void FileInfoManager::remove(QString uri)
-{
-    ThumbnailManager::getInstance()->releaseThumbnail(uri);
-    Q_ASSERT(global_info_list);
-    global_info_list->remove(uri);
-}
-
-void FileInfoManager::remove(std::shared_ptr<FileInfo> info)
-{
-    Q_ASSERT(global_info_list);
-    this->remove(info->uri());
-}
-
 void FileInfoManager::showState()
 {
     qDebug()<<global_info_list->keys().count()<<global_info_list->values().count();
