@@ -126,7 +126,7 @@ public:
      * \return
      * \deprecated
      */
-    static std::shared_ptr<FileInfo> fromUri(QString uri, bool addToHash = true);
+    static std::shared_ptr<FileInfo> fromUri(QString uri);
     /*!
      * \brief fromPath
      * \param path
@@ -134,7 +134,7 @@ public:
      * \return
      * \deprecated
      */
-    static std::shared_ptr<FileInfo> fromPath(QString path, bool addToHash = true);
+    static std::shared_ptr<FileInfo> fromPath(QString path);
     /*!
      * \brief fromGFile
      * \param file
@@ -142,7 +142,7 @@ public:
      * \return
      * \deprecated
      */
-    static std::shared_ptr<FileInfo> fromGFile(GFile *file, bool addToHash = true);
+    static std::shared_ptr<FileInfo> fromGFile(GFile *file);
 
     QString uri() {
         return m_uri;
@@ -164,10 +164,6 @@ public:
         return m_is_valid;
     }
 
-    QString displayName() {
-        return m_display_name;
-    }
-
     QString desktopName(){
         return m_desktop_name;
     }
@@ -201,10 +197,19 @@ public:
     QString accessDate() {
         return m_access_date;
     }
+    QString deletionDate() {
+        return m_deletion_date;
+    }
+
 
     QString type() {
         return m_content_type;
     }
+
+    QString fileSystemType() {
+        return m_fs_type;
+    }
+
     quint64 size() {
         return m_size;
     }
@@ -214,6 +219,9 @@ public:
     quint64 accessTime() {
         return m_access_time;
     }
+    quint64 deletionTime() {
+        return m_deletion_date_uint64;
+    }
 
     QList<QColor> getColors() {
         return m_colors;
@@ -253,9 +261,6 @@ public:
     bool canStop() {
         return m_can_stop;
     }
-    QString unixDeviceFile() {
-        return QString(m_unix_device_file);
-    }
 
     bool isDesktopFile() {
         return m_can_excute && m_uri.endsWith(".desktop");
@@ -263,18 +268,21 @@ public:
 
     bool isPdfFile(){
         return m_mime_type_string.contains("pdf");
-
     }
 
     bool isImageFile(){
         return m_mime_type_string.startsWith("image/");
     }
 
+    bool isImagePdfFile(){
+        return m_mime_type_string.contains("djvu");
+    }
+
     bool isVideoFile();
     bool isOfficeFile();
 
     bool isEmptyInfo() {
-        return m_display_name == nullptr;
+        return m_display_name == nullptr || m_display_name == "";
     }
 
     AccessFlags accesses() {
@@ -309,7 +317,13 @@ public:
     }
 
     const QString targetUri();
+    const QString displayName();
     const QString symlinkTarget();
+    const QString unixDeviceFile();
+
+    const QString customIcon();
+
+    quint64 getDeletionDateUInt64();
 
     //const QIcon thumbnail() {return m_thumbnail;}
     //void setThumbnail(const QIcon &thumbnail) {m_thumbnail = thumbnail;}
@@ -338,6 +352,7 @@ private:
     guint64 m_size = 0;
     guint64 m_modified_time = 0;
     guint64 m_access_time = 0;
+    guint64 m_deletion_date_uint64 = 0;
 
     /*!
      * \deprecated
@@ -349,6 +364,7 @@ private:
     QString m_file_size = nullptr;
     QString m_modified_date = nullptr;
     QString m_access_date = nullptr;
+    QString m_deletion_date = nullptr;
 
     //access
     bool m_can_read = true;
@@ -364,7 +380,7 @@ private:
 
     bool m_can_start = false;
     bool m_can_stop = false;
-    const char *m_unix_device_file = nullptr;
+    QString m_unix_device_file;
 
     //FIXME: should i use smart pointer wrap these data?
     GFile *m_file = nullptr;
@@ -373,6 +389,9 @@ private:
     QString m_target_uri;
     QString m_symlink_target;
 
+    // filesystem
+    QString m_fs_type;
+
     /*!
      * \brief m_cancellable
      * This cancellable is used in async query file info in FileInfoJob instance.
