@@ -187,6 +187,13 @@ FileOperationProgressBar::FileOperationProgressBar(QWidget *parent) : QWidget(pa
     connect(m_other_progressbar, &OtherButton::clicked, this, &FileOperationProgressBar::showWidgetList);
     connect(m_list_widget, &QListWidget::itemClicked, this, &FileOperationProgressBar::mainProgressChange);
 
+    connect(this, &FileOperationProgressBar::pause, this, [=] () {
+        m_main_progressbar->setPause();
+        for (auto pb : m_progress_list->keys()) {
+            pb->setPause();
+        }
+    });
+
     showMore();
 }
 
@@ -270,6 +277,8 @@ void FileOperationProgressBar::mainProgressChange(QListWidgetItem *item)
     if (m_current_main->getStatus()) {
         m_main_progressbar->cancelld();
     }
+    m_main_progressbar->setFileName(pb->getFileName());
+    m_main_progressbar->setProgress(pb->getProgress());
     m_main_progressbar->setFileIcon(m_current_main->getIcon());
     m_main_progressbar->connect(m_current_main, &ProgressBar::cancelled, m_main_progressbar, &MainProgressBar::cancelld);
     m_main_progressbar->connect(m_current_main, &ProgressBar::sendValue, m_main_progressbar, &MainProgressBar::updateValue);
@@ -280,6 +289,7 @@ void FileOperationProgressBar::mainProgressChange(QListWidgetItem *item)
         m_main_progressbar->setResume();
     }
 
+    m_main_progressbar->setIsSync(pb->m_sync);
     m_current_main->connect(m_main_progressbar, &MainProgressBar::pause, this, [=] () {
         m_current_main->setPause();
         m_main_progressbar->setPause();
@@ -334,11 +344,28 @@ void MainProgressBar::setTitle(QString title)
 void MainProgressBar::setPause()
 {
     m_pause = true;
+    update();
 }
 
 void MainProgressBar::setResume()
 {
     m_pause = false;
+    update();
+}
+
+void MainProgressBar::setIsSync(bool sync)
+{
+    m_sync = sync;
+}
+
+void MainProgressBar::setProgress(float val)
+{
+    m_current_value = val;
+}
+
+void MainProgressBar::setFileName(QString name)
+{
+    m_file_name = name;
 }
 
 void MainProgressBar::paintEvent(QPaintEvent *event)
@@ -405,10 +432,8 @@ void MainProgressBar::mouseReleaseEvent(QMouseEvent *event)
                && (pos.y() >= m_progress_pause_y)
                && (pos.y() <= m_progress_pause_y_b)) {
         if (m_pause) {
-            m_pause = false;
             Q_EMIT start();
         } else {
-            m_pause = true;
             Q_EMIT pause();
         }
     }
@@ -509,7 +534,10 @@ void MainProgressBar::paintProgress(QPainter &painter)
 
     painter.setPen(Qt::NoPen);
     painter.setBrush(QBrush(btn->palette().color(QPalette::Highlight).lighter(150)));
-    painter.drawRoundedRect(0, 0, value, m_fix_height, 1, 1);
+
+    if (value < 1) {
+        painter.drawRoundedRect(0, 0, value, m_fix_height, 1, 1);
+    }
 
     painter.restore();
 }
@@ -522,7 +550,7 @@ void MainProgressBar::cancelld()
 
 void MainProgressBar::updateValue(QString& name, QIcon& icon, double value)
 {
-    if (value >= 0 && value <= 1) {
+    if (value >= 0 && value < 1) {
         m_current_value = value;
     }
 
@@ -639,6 +667,11 @@ float ProgressBar::getTotalSize()
     return m_total_size;
 }
 
+QString ProgressBar::getFileName()
+{
+    return m_dest_uri;
+}
+
 bool ProgressBar::isPause()
 {
     return m_pause;
@@ -688,6 +721,9 @@ void ProgressBar::paintEvent(QPaintEvent *event)
     painter.setFont(font);
     if (m_is_stopping) {
         painter.drawText(m_text_x, m_text_y, m_text_w, m_text_height, Qt::AlignLeft | Qt::AlignVCenter, tr("canceling ..."));
+    } else if (m_sync) {
+        painter.drawText(m_text_x, m_text_y, m_text_w, m_text_height, Qt::AlignLeft | Qt::AlignVCenter, tr("sync ..."));
+        painter.drawPixmap(m_pause_x, m_pause_y, QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_btn_size, m_btn_size));
     } else {
         painter.drawText(m_text_x, m_text_y, m_text_w, m_text_height, Qt::AlignLeft | Qt::AlignVCenter, m_dest_uri);
     }
@@ -705,13 +741,15 @@ void ProgressBar::paintEvent(QPaintEvent *event)
     painter.setBrush(QBrush(btn->palette().color(QPalette::Highlight)));
     painter.drawRoundedRect(m_progress_x, m_progress_y, value, m_progress_height, 1, 1);
 
-    // paint stop
-    if (m_pause) {
-        painter.drawPixmap(m_pause_x, m_pause_y, QIcon::fromTheme("media-playback-start-symbolic").pixmap(m_btn_size, m_btn_size));
-    } else {
-        painter.drawPixmap(m_pause_x, m_pause_y, QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_btn_size, m_btn_size));
+    if (!m_sync) {
+        if (m_pause) {
+            painter.drawPixmap(m_pause_x, m_pause_y, QIcon::fromTheme("media-playback-start-symbolic").pixmap(m_btn_size, m_btn_size));
+        } else {
+            painter.drawPixmap(m_pause_x, m_pause_y, QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_btn_size, m_btn_size));
+        }
     }
 
+
     // paint close
     painter.drawPixmap(m_close_x, m_close_y, m_btn_size, m_btn_size,
                        drawSymbolicColoredPixmap(QIcon::fromTheme("window-close-symbolic").pixmap(m_btn_size, m_btn_size)));
@@ -815,6 +853,7 @@ void ProgressBar::onFileOperationProgressedOne(const QString &uri, const QString
 void ProgressBar::updateProgress(const QString &srcUri, const QString &destUri, const QString& fIcon, const quint64& current, const quint64& total)
 {
     if (current >= m_total_size) {
+        qDebug() << "progress bar value error!";
         return;
     }
 
@@ -828,6 +867,9 @@ void ProgressBar::updateProgress(const QString &srcUri, const QString &destUri,
     }
 
     double currentPercent = current * 1.0 / total;
+
+//    qDebug() << "progress bar: " << currentPercent;
+
     updateValue(currentPercent);
 
     Q_UNUSED(srcUri);
@@ -852,7 +894,7 @@ void ProgressBar::switchToRollbackPage()
 
 void ProgressBar::onStartSync()
 {
-
+    m_sync = true;
 }
 
 void ProgressBar::onFinished()
