@@ -1,7 +1,7 @@
 /*
  * Peony-Qt's Library
  *
- * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020, KylinSoft Co., Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,8 @@
 
 #include "peony-core_global.h"
 #include "file-operation.h"
+#include "file-node.h"
+#include "file-info.h"
 
 namespace Peony {
 
@@ -34,12 +36,24 @@ class PEONYCORESHARED_EXPORT FileTrashOperation : public FileOperation
 public:
     explicit FileTrashOperation(QStringList srcUris, QObject *parent = nullptr);
 
-    std::shared_ptr<FileOperationInfo> getOperationInfo() override {return m_info;}
+    std::shared_ptr<FileOperationInfo> getOperationInfo() override {
+        return m_info;
+    }
     void run() override;
 
 private:
+    void forceDelete (QString uri);
+    void setErrorMessage (GError** err);
+    void deleteRecursively(FileNode *node);
+
+private:
+    int m_current_count = 0;
+    int m_total_count = 0;
     QStringList m_src_uris;
     std::shared_ptr<FileOperationInfo> m_info = nullptr;
+
+    // record source file infos before trashed, only used in native fs
+    QList<std::shared_ptr<FileInfo>> m_src_infos;
 };
 
 }
