@@ -85,6 +85,33 @@ GlobalSettings::GlobalSettings(QObject *parent) : QObject(parent)
         setDateFormat(dateValue);
     }
 
+    m_cache.insert(SHOW_TRASH_DIALOG, true);
+    m_cache.insert(SHOW_HIDDEN_PREFERENCE, false);
+    if (QGSettings::isSchemaInstalled("org.ukui.peony.settings")) {
+        m_peony_gsettings = new QGSettings("org.ukui.peony.settings", QByteArray(), this);
+        connect(m_peony_gsettings, &QGSettings::changed, this, [=](const QString &key) {
+            if (key == "showTrashDialog") {
+                m_cache.remove(SHOW_TRASH_DIALOG);
+                m_cache.insert(SHOW_TRASH_DIALOG, m_peony_gsettings->get(key).toBool());
+            } else if (SHOW_HIDDEN_PREFERENCE == key) {
+                if (m_cache.value(key) != m_peony_gsettings->get(key).toBool())
+                {
+                    m_cache.remove(key);
+                    m_cache.insert(key, m_peony_gsettings->get(key).toBool());                  
+                }
+                /* Solve the problem: When opening multiple document management, check "Show hidden files" in one document management,
+                 *  but the other document management does not take effect in real time.modified by 2021/06/15  */
+                Q_EMIT this->valueChanged(key);
+            }
+        });
+
+        m_cache.remove(SHOW_TRASH_DIALOG);
+        m_cache.insert(SHOW_TRASH_DIALOG, m_peony_gsettings->get(SHOW_TRASH_DIALOG).toBool());
+
+        m_cache.remove(SHOW_HIDDEN_PREFERENCE);
+        m_cache.insert(SHOW_HIDDEN_PREFERENCE, m_peony_gsettings->get(SHOW_HIDDEN_PREFERENCE).toBool());
+    }
+
     m_cache.insert(SIDEBAR_BG_OPACITY, 50);
     if (QGSettings::isSchemaInstalled("org.ukui.style")) {
         m_gsettings = new QGSettings("org.ukui.style", QByteArray(), this);
@@ -129,8 +156,8 @@ GlobalSettings::GlobalSettings(QObject *parent) : QObject(parent)
         setValue(DEFAULT_VIEW_ZOOM_LEVEL, 25);
     }
 
-    if (m_cache.value(REMOTE_SERVER_IP).isNull()) {
-        setValue(REMOTE_SERVER_IP, QVariant(QList<QString>()));
+    if (m_cache.value(REMOTE_SERVER_REMOTE_IP).isNull()) {
+        setValue(REMOTE_SERVER_REMOTE_IP, QVariant(QList<QString>()));
     }
 }
 
@@ -180,6 +207,8 @@ void GlobalSettings::resetAll()
 
 void GlobalSettings::setValue(const QString &key, const QVariant &value)
 {
+
+    m_cache.remove(key);
     m_cache.insert(key, value);
     QtConcurrent::run([=]() {
         if (m_mutex.tryLock(1000)) {
@@ -204,6 +233,11 @@ void GlobalSettings::forceSync(const QString &key)
     }
 }
 
+void GlobalSettings::slot_updateRemoteServer(const QString& server, bool add)
+{
+    Q_EMIT signal_updateRemoteServer(server, add);
+}
+
 void GlobalSettings::setTimeFormat(const QString &value)
 {
     if (value == "12"){
@@ -229,3 +263,16 @@ QString GlobalSettings::getSystemTimeFormat()
     m_system_time_format = m_date_format + " " + m_time_format;
     return m_system_time_format;
 }
+void GlobalSettings::setGSettingValue(const QString &key, const QVariant &value)
+{
+    if (!m_peony_gsettings)
+        return;
+
+    const QStringList list = m_peony_gsettings->keys();
+    if (!list.contains(key))
+        return;
+
+    m_peony_gsettings->set(key, value);
+    m_cache.remove(key);
+    m_cache.insert(key, m_peony_gsettings->get(key));
+}
