@@ -46,8 +46,17 @@
 
 #include <QApplication>
 
+#include <QTime>
+
 using namespace Peony;
 
+QString uri2FavoriteUri(const QString &sourceUri)
+{
+    QUrl url = sourceUri;
+    QString favoriteUri = "favorite://" + url.path() + "?schema=" + url.scheme();
+    return favoriteUri;
+}
+
 FileItem::FileItem(std::shared_ptr<Peony::FileInfo> info, FileItem *parentItem, FileItemModel *model, QObject *parent) : QObject(parent)
 {
     m_parent = parentItem;
@@ -58,6 +67,68 @@ FileItem::FileItem(std::shared_ptr<Peony::FileInfo> info, FileItem *parentItem,
 
     m_backend_enumerator = new FileEnumerator(this);
 
+    m_idle = new QTimer(this);
+    m_idle->setInterval(0);
+    m_idle->setSingleShot(true);
+    connect(m_idle, &QTimer::timeout, this, [=]{
+        if (m_uris_to_be_removed.isEmpty())
+            return;
+
+        QStringList favoriteUris;
+
+        if (m_uris_to_be_removed.count() < 10) {
+            // do normal remove
+            for (auto uri : m_uris_to_be_removed) {
+                for (int row = 0; row < m_children->count(); row++) {
+                    auto child = m_children->at(row);
+                    // 此处实际可靠性还有待验证
+                    if (FileUtils::isSamePath(uri, child->uri())) {
+                        auto info = child->m_info;
+                        if (info->isDir())
+                        {
+                            favoriteUris.append(uri2FavoriteUri(uri));
+                        }
+                        m_model->beginRemoveRows(this->firstColumnIndex(), row, row);
+                        m_children->remove(row);
+                        delete child;
+                        m_model->endRemoveRows();
+                        break;
+                    }
+                }
+            }
+            BookMarkManager::getInstance()->removeBookMark(favoriteUris);
+            return;
+        }
+
+        // do reset model
+
+        int time0 = QTime::currentTime().msecsSinceStartOfDay();
+        qDebug()<<"execute deletion";
+        m_model->beginResetModel();
+        qDebug()<<"files deleted"<<m_uris_to_be_removed.count();
+        for (auto uri : m_uris_to_be_removed) {
+            for (int row = 0; row < m_children->count(); row++) {
+                auto child = m_children->at(row);
+                // 此处实际可靠性还有待验证
+                if (FileUtils::isSamePath(uri, child->uri())) {
+                    auto info = child->m_info;
+                    if (info->isDir())
+                    {
+                        favoriteUris.append(uri2FavoriteUri(uri));
+                    }
+                    m_children->remove(row);
+                    delete child;
+                    break;
+                }
+            }
+        }
+        m_model->endResetModel();
+        BookMarkManager::getInstance()->removeBookMark(favoriteUris);
+        int time1 = QTime::currentTime().msecsSinceStartOfDay();
+        qDebug()<<"excute deletion finished, cost"<<time1 - time0;
+        //ThumbnailManager::getInstance()->releaseThumbnail(m_uris_to_be_removed);
+    });
+
     m_thumbnail_watcher = std::make_shared<Peony::FileWatcher>("thumbnail://");
     connect(m_thumbnail_watcher.get(), &FileWatcher::fileChanged, this, [=](const QString &uri){
         auto index = m_model->indexFromUri(uri);
@@ -155,6 +226,8 @@ void FileItem::findChildrenAsync()
             //Peony::AudioPlayManager::getInstance()->playWarningAudio();
             QMessageBox::critical(nullptr, tr("Error"), err->message());
             enumerator->cancel();
+            //fix bug#77594
+            enumerator->deleteLater();
             return;
         }
 
@@ -192,9 +265,9 @@ void FileItem::findChildrenAsync()
                     BookMarkManager::getInstance()->removeBookMark(uri2FavoriteUri(this->uri()));
                     m_model->sendPathChangeRequest("computer:///");
                 }
-                else
+                else {
                     m_model->setRootUri(FileUtils::getParentUri(this->uri()));
-
+                }
                 auto fileInfo = FileInfo::fromUri(this->uri());
                 if (err.get()->code() == G_IO_ERROR_NOT_FOUND && fileInfo->isSymbolLink())
                 {
@@ -296,17 +369,7 @@ void FileItem::findChildrenAsync()
                 qDebug() << "inpositive Model onChildAdded:" <<uri;
             });
             connect(m_watcher.get(), &FileWatcher::fileDeleted, this, [=](QString uri) {
-                //check bookmark and delete
-                auto info = FileInfo::fromUri(uri);
-                if (info->isDir())
-                {
-                    BookMarkManager::getInstance()->removeBookMark(uri2FavoriteUri(uri));
-                }
-                //remove the crosponding child
-                //tell the model update
                 this->onChildRemoved(uri);
-                Q_EMIT this->childRemoved(uri);
-                ThumbnailManager::getInstance()->releaseThumbnail(uri);
             });
             connect(m_watcher.get(), &FileWatcher::fileChanged, this, [=](const QString &uri) {
                 auto index = m_model->indexFromUri(uri);
@@ -315,7 +378,7 @@ void FileItem::findChildrenAsync()
                     infoJob->setAutoDelete();
                     connect(infoJob, &FileInfoJob::queryAsyncFinished, this, [=]() {
                         m_model->dataChanged(m_model->indexFromUri(uri), m_model->indexFromUri(uri));
-                        auto info = FileInfo::fromUri(uri);
+                        //auto info = FileInfo::fromUri(uri);
                         ThumbnailManager::getInstance()->createThumbnail(uri, m_thumbnail_watcher, true);
                         /*
                         if (info->isDesktopFile()) {
@@ -417,21 +480,11 @@ void FileItem::findChildrenAsync()
                 this->onChildAdded(uri);
                 Q_EMIT this->childAdded(uri);
                 qDebug() << "positive onChildAdded:" <<uri;
-                ThumbnailManager::getInstance()->createThumbnail(uri, m_thumbnail_watcher);
+                //file changed, force create thubnail, link tobug#83108
+                ThumbnailManager::getInstance()->createThumbnail(uri, m_thumbnail_watcher, true);
             });
             connect(m_watcher.get(), &FileWatcher::fileDeleted, this, [=](QString uri) {
-                //check bookmark and delete
-                auto info = FileInfo::fromUri(uri);
-                if (info->isDir())
-                {
-                    BookMarkManager::getInstance()->removeBookMark(uri2FavoriteUri(uri));
-                }
-                //remove the crosponding child
-                //tell the model update
                 this->onChildRemoved(uri);
-                Q_EMIT this->childRemoved(uri);
-                qDebug() << "childRemoved:" <<uri;
-                ThumbnailManager::getInstance()->releaseThumbnail(uri);
             });
             connect(m_watcher.get(), &FileWatcher::fileChanged, this, [=](const QString &uri) {
                 auto index = m_model->indexFromUri(uri);
@@ -440,16 +493,18 @@ void FileItem::findChildrenAsync()
                     infoJob->setAutoDelete();
                     connect(infoJob, &FileInfoJob::queryAsyncFinished, this, [=]() {
                         m_model->dataChanged(m_model->indexFromUri(uri), m_model->indexFromUri(uri));
-                        auto info = FileInfo::fromUri(uri);
-                        if (info->isDesktopFile()) {
-                            ThumbnailManager::getInstance()->updateDesktopFileThumbnail(info->uri(), m_watcher);
-                        }
+                        //comment to fix endless loop and can not rename issue, related to bug#72642
+//                        auto info = FileInfo::fromUri(uri);
+//                        if (info->isDesktopFile()) {
+//                            ThumbnailManager::getInstance()->updateDesktopFileThumbnail(info->uri(), m_watcher);
+//                        }
                     });
                     infoJob->queryAsync();
                 }
             });
             connect(m_watcher.get(), &FileWatcher::fileRenamed, this, [=](const QString &oldUri, const QString &newUri) {
                 this->onRenamed(oldUri, newUri);
+                BookMarkManager::getInstance()->bookmarkChanged(oldUri, newUri);
             });
             connect(m_watcher.get(), &FileWatcher::thumbnailUpdated, this, [=](const QString &uri) {
                 m_model->dataChanged(m_model->indexFromUri(uri), m_model->indexFromUri(uri));
@@ -516,6 +571,8 @@ FileItem *FileItem::getChildFromUri(QString uri)
 
 void FileItem::onChildAdded(const QString &uri)
 {
+    m_uris_to_be_removed.removeOne(uri);
+
     qDebug()<<"add child:" << uri;
     FileItem *child = getChildFromUri(uri);
     if (child) {
@@ -571,17 +628,11 @@ void FileItem::onChildRemoved(const QString &uri)
 {
     // fix #62925
     m_waiting_add_queue.removeOne(uri);
-
-    FileItem *child = getChildFromUri(uri);
-    if (child) {
-        int index = m_children->indexOf(child);
-        m_model->beginRemoveRows(this->firstColumnIndex(), index, index);
-        m_children->removeOne(child);
-        qDebug() <<"successfully removed child:" <<uri;
-        delete child;
-        m_model->endRemoveRows();
+    m_uris_to_be_removed.append(uri);
+    if (!m_idle->isActive()) {
+        m_idle->start();
     }
-    m_model->updated();
+    return;
 }
 
 void FileItem::onDeleted(const QString &thisUri)
@@ -615,7 +666,10 @@ void FileItem::onDeleted(const QString &thisUri)
             tmpItem = tmpItem->m_parent;
         }
         if (!tmpUri.isNull()) {
-            m_model->setRootUri(tmpUri);
+            if(tmpUri.startsWith("file:///media"))
+                m_model->sendPathChangeRequest("computer:///");
+            else
+                m_model->setRootUri(tmpUri);
         } else {
             m_model->setRootUri("file:///");
         }
@@ -627,13 +681,37 @@ void FileItem::onRenamed(const QString &oldUri, const QString &newUri)
 {
     qDebug()<<"renamed";
 
-    FileItem *child = getChildFromUri(oldUri);
-    if (child) {
-       int index = m_children->indexOf(child);
-        m_children->at(index)->m_info= FileInfo::fromUri(newUri);
-        child->updateInfoAsync();
+    // fix #77076, which caused by idle removing item due to #66255.
+    if (m_uris_to_be_removed.contains(newUri)) {
+        m_uris_to_be_removed.removeOne(newUri);
     }
 
+    // note that some times new file has arealy in directory view,
+    // and there is no delete event triggered. for example. copy
+    // a .desktop file in current view. in this case there might
+    // be an outdated tmp file left.
+    //
+    // to avoid that we add an existing checkment, and handle old
+    // file with different situation.
+    auto newChild = getChildFromUri(newUri);
+    if (newChild) {
+        qDebug()<<"new child has arealy in view";
+        newChild->updateInfoAsync();
+    }
+
+    FileItem *child = getChildFromUri(oldUri);
+    if (child) {
+        if (!newChild) {
+            int index = m_children->indexOf(child);
+            m_children->at(index)->m_info= FileInfo::fromUri(newUri);
+            child->updateInfoAsync();
+        } else {
+            m_model->beginRemoveRows(this->firstColumnIndex(), m_children->indexOf(child), m_children->indexOf(child));
+            m_children->removeOne(child);
+            child->deleteLater();
+            m_model->endRemoveRows();
+        }
+    }
 }
 
 void FileItem::onUpdateDirectoryRequest()
@@ -648,15 +726,22 @@ void FileItem::onUpdateDirectoryRequest()
         QStringList rawUris;
         QStringList removedUris;
         QStringList addedUris;
+        QVector<FileItem*> removeFileItem ;
 
         for (auto child : *m_model->m_root_item->m_children) {
             rawUris<<child->uri();
             if (!currentUris.contains(child->uri())) {
                 removedUris<<child->uri();
-                m_model->m_root_item->onChildRemoved(child->uri());
+                removeFileItem.append(child);
+                //m_model->m_root_item->onChildRemoved(child->uri());
             }
         }
 
+        for (auto item : removeFileItem ) {
+            m_model->m_root_item->onChildRemoved(item->uri());
+        }
+
+
         for (auto uri : currentUris) {
             if (!rawUris.contains(uri)) {
                 addedUris<<uri;
@@ -697,6 +782,11 @@ void FileItem::updateInfoAsync()
     job->queryAsync();
 }
 
+void FileItem::removeChildren()
+{
+
+}
+
 void FileItem::clearChildren()
 {
     auto parent = firstColumnIndex();
@@ -741,10 +831,3 @@ bool FileItem::shouldShow()
     }
     return true;
 }
-
-QString FileItem::uri2FavoriteUri(const QString &sourceUri)
-{
-    QUrl url = sourceUri;
-    QString favoriteUri = "favorite://" + url.path() + "?schema=" + url.scheme();
-    return favoriteUri;
-}
