@@ -29,6 +29,8 @@
 #include <QObject>
 #include <QVector>
 
+class QTimer;
+
 namespace Peony {
 
 class FileInfo;
@@ -91,6 +93,7 @@ public:
     QModelIndex lastColumnIndex();
 
     bool hasChildren();
+    bool shouldShow();
 
 Q_SIGNALS:
     void cancelFindChildren();
@@ -140,6 +143,8 @@ protected:
      */
     void updateInfoAsync();
 
+    void removeChildren();
+
 private:
     FileItem *m_parent = nullptr;
     std::shared_ptr<Peony::FileInfo> m_info;
@@ -153,6 +158,11 @@ private:
     std::shared_ptr<FileWatcher> m_thumbnail_watcher = nullptr;
 
     QStringList m_ending_uris;
+    QStringList m_waiting_add_queue;
+
+    QStringList m_uris_to_be_removed;
+    QTimer *m_idle = nullptr;
+
 
     /*!
      * \brief m_async_count
