@@ -84,9 +84,9 @@ using namespace Peony;
 FMWindow::FMWindow(const QString &uri, QWidget *parent) : QMainWindow (parent)
 {
     auto settings = GlobalSettings::getInstance();
-    m_show_hidden_file = settings->isExist("show-hidden")? settings->getValue("show-hidden").toBool(): false;
-    m_use_default_name_sort_order = settings->isExist("chinese-first")? settings->getValue("chinese-first").toBool(): false;
-    m_folder_first = settings->isExist("folder-first")? settings->getValue("folder-first").toBool(): true;
+    m_show_hidden_file = settings->isExist(SHOW_HIDDEN_PREFERENCE)? settings->getValue(SHOW_HIDDEN_PREFERENCE).toBool(): false;
+    m_use_default_name_sort_order = settings->isExist(SORT_CHINESE_FIRST)? settings->getValue(SORT_CHINESE_FIRST).toBool(): false;
+    m_folder_first = settings->isExist(SORT_FOLDER_FIRST)? settings->getValue(SORT_FOLDER_FIRST).toBool(): true;
 
     setWindowIcon(QIcon::fromTheme("system-file-manager"));
     setWindowTitle(tr("File Manager"));
@@ -291,20 +291,20 @@ FMWindow::FMWindow(const QString &uri, QWidget *parent) : QMainWindow (parent)
         m_tool_bar->updateStates();
     });
 
-    //search
-    connect(m_search_bar, &SearchBar::searchKeyChanged, [=]() {
-        //FIXME: filter the current directory
-    });
-    connect(m_search_bar, &SearchBar::searchRequest, [=](const QString &key) {
-        QString uri = this->getCurrentUri();
-        if (uri.startsWith("search:///")) {
-            uri = m_last_non_search_location;
-        }
-        m_update_condition = false; //common search, no filter
-        auto targetUri = SearchVFSUriParser::parseSearchKey(uri, key);
-        this->goToUri(targetUri, true);
-        m_clear_record->setDisabled(false); //has record to clear
-    });
+    //search, comment old code
+//    connect(m_search_bar, &SearchBar::searchKeyChanged, [=]() {
+//        //FIXME: filter the current directory
+//    });
+//    connect(m_search_bar, &SearchBar::searchRequest, [=](const QString &key) {
+//        QString uri = this->getCurrentUri();
+//        if (uri.startsWith("search:///")) {
+//            uri = m_last_non_search_location;
+//        }
+//        m_update_condition = false; //common search, no filter
+//        auto targetUri = SearchVFSUriParser::parseSearchKey(uri, key);
+//        this->goToUri(targetUri, true);
+//        m_clear_record->setDisabled(false); //has record to clear
+//    });
 
     //action
     QAction *stopLoadingAction = new QAction(this);
