@@ -23,18 +23,16 @@
 #ifndef FORMAT_DIALOG_H
 #define FORMAT_DIALOG_H
 
-#include <QDialog>
-#include <sys/stat.h>
-#include <udisks/udisks.h>
-#include <libnotify/notify.h>
-#include <glib/gi18n.h>
 #include <QTimer>
 #include <errno.h>
+#include <QDialog>
+#include <sys/stat.h>
+#include <glib/gi18n.h>
+#include <udisks/udisks.h>
+#include <libnotify/notify.h>
+
+#include "peony-core_global.h"
 
-#include "side-bar-menu.h"
-#include "volume-manager.h"
-#include "file-utils.h"
-#include "side-bar-abstract-item.h"
 namespace Ui {
 class Format_Dialog;
 }
@@ -61,7 +59,7 @@ struct CreateformatData{
 };
 
 
-class Format_Dialog : public QDialog
+class PEONYCORESHARED_EXPORT Format_Dialog : public QDialog
 {
     Q_OBJECT
 
@@ -79,7 +77,6 @@ public:
     UDisksObject *get_object_from_block_device 	(UDisksClient *client,
                                                  const gchar *block_device);
 
-
     void kdisk_format(const gchar * device_name,const gchar *format_type,
                       const gchar * erase_type,const gchar * filesystem_name,int *format_finish);
 
@@ -105,7 +102,11 @@ public:
 
     int m_cost_seconds = 0;
 
-    int m_total_predict = 3600;
+    int m_total_predict = 1200;
+
+    double m_simulate_progress = 0;
+
+    void closeEvent(QCloseEvent* );
 
 Q_SIGNALS:
      void ensure_format(bool flags);
@@ -115,13 +116,8 @@ public Q_SLOTS:
     void acceptFormat (bool);
     void colseFormat(bool);
 
-
     void formatloop();
-
-
-
 private:
-
     QString fm_uris;
     SideBarAbstractItem *fm_item;
 
