@@ -134,7 +134,7 @@ void DesktopIconViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
     int y_delta = iconSizeExpected.height() - iconRect.height();
     opt.rect.translate(0, y_delta);
 
-    int maxTextHight = opt.rect.height() - iconSizeExpected.height() - 10;
+    int maxTextHight = opt.rect.height() - iconSizeExpected.height() + 10;
     if (maxTextHight < 0) {
         maxTextHight = 0;
     }
@@ -386,10 +386,17 @@ void DesktopIconViewDelegate::setEditorData(QWidget *editor, const QModelIndex &
     cursor.setPosition(0, QTextCursor::MoveAnchor);
     cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
     bool isDir = FileUtils::getFileIsFolder(index.data(Qt::UserRole).toString());
-    if (!isDir && edit->toPlainText().contains(".") && !edit->toPlainText().startsWith(".")) {
-        cursor.movePosition(QTextCursor::WordLeft, QTextCursor::KeepAnchor, 1);
-        cursor.movePosition(QTextCursor::Left, QTextCursor::KeepAnchor, 1);
-        //qDebug()<<cursor.position();
+    bool isDesktopFile = index.data(Qt::UserRole).toString().endsWith(".desktop");
+    bool isSoftLink = FileUtils::getFileIsSymbolicLink(index.data(Qt::UserRole).toString());
+    if (!isDesktopFile && !isSoftLink && !isDir && edit->toPlainText().contains(".") && !edit->toPlainText().startsWith(".")) {
+        int n = 1;
+        if(index.data(Qt::DisplayRole).toString().contains(".tar.")) //ex xxx.tar.gz xxx.tar.bz2
+            n = 2;
+        while(n){
+            cursor.movePosition(QTextCursor::WordLeft, QTextCursor::KeepAnchor, 1);
+            cursor.movePosition(QTextCursor::Left, QTextCursor::KeepAnchor, 1);
+            --n;
+        }
     }
     //qDebug()<<cursor.anchor();
     edit->setTextCursor(cursor);
@@ -422,7 +429,7 @@ void DesktopIconViewDelegate::setModelData(QWidget *editor, QAbstractItemModel *
     if (newName.isNull())
         return;
     //process special name . or .. or only space
-    if (newName == "." || newName == ".." || newName.trimmed() == "" || newName.contains("\\"))
+    if (newName == "." || newName == ".." || newName.trimmed() == "")
         newName = "";
     //comment new name != suffix check to fix feedback issue
     if (newName.length() >0 && newName != oldName/* && newName != suffix*/) {
