@@ -40,7 +40,6 @@
 #include "file-operation-utils.h"
 
 #include "desktop-menu.h"
-#include "desktop-window.h"
 
 #include "file-item-model.h"
 #include "file-info-job.h"
@@ -138,69 +137,6 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
     auto zoomLevel = this->zoomLevel();
     setDefaultZoomLevel(zoomLevel);
 
-//#if QT_VERSION > QT_VERSION_CHECK(5, 12, 0)
-//    QTimer::singleShot(500, this, [=](){
-//#else
-//    QTimer::singleShot(500, [=](){
-//#endif
-//        connect(this->selectionModel(), &QItemSelectionModel::selectionChanged, [=](const QItemSelection &selection, const QItemSelection &deselection){
-//            //qDebug()<<"selection changed";
-//            m_real_do_edit = false;
-//            this->setIndexWidget(m_last_index, nullptr);
-//            auto currentSelections = this->selectionModel()->selection().indexes();
-
-//            if (currentSelections.count() == 1) {
-//                //qDebug()<<"set index widget";
-//                m_last_index = currentSelections.first();
-//                auto delegate = qobject_cast<DesktopIconViewDelegate *>(itemDelegate());
-//                this->setIndexWidget(m_last_index, new DesktopIndexWidget(delegate, viewOptions(), m_last_index, this));
-//            } else {
-//                m_last_index = QModelIndex();
-//                for (auto index : deselection.indexes()) {
-//                    this->setIndexWidget(index, nullptr);
-//                }
-//            }
-//        });
-//    });
-
-    auto screens = qApp->screens();
-    if (QString(qgetenv("DESKTOP_SESSION")) != "ukui-wayland") {
-        connect(qApp->primaryScreen(), &QScreen::geometryChanged, this, QOverload<const QRect &>::of(&DesktopIconView::setGeometry));
-    }
-    connect(qApp, &QGuiApplication::screenAdded, [=] (QScreen* screen) {
-        m_screens[screen] = false;
-        for (auto it = m_screens.constBegin(); it != m_screens.constEnd(); ++it) {
-            m_screens[screen] = (screen == qApp->primaryScreen()) ? true : false;
-        }
-    });
-
-    connect(qApp, &QGuiApplication::screenRemoved, [=] (QScreen* screen) {
-        m_screens.remove(screen);
-        for (auto it = m_screens.constBegin(); it != m_screens.constEnd(); ++it) {
-            m_screens[screen] = (screen == qApp->primaryScreen()) ? true : false;
-        }
-    });
-
-    if (QString(qgetenv("DESKTOP_SESSION")) != "ukui-wayland") {
-        connect(qApp, &QGuiApplication::primaryScreenChanged, [=] (QScreen* screen) {
-            for (auto it = m_screens.constBegin(); it != m_screens.constEnd(); ++it) {
-                if (it.value()) {
-                    disconnect(it.key(), &QScreen::geometryChanged, this, QOverload<const QRect &>::of(&DesktopIconView::setGeometry));
-                }
-                m_screens[it.key()] = false;
-            }
-
-            m_screens[screen] = true;
-            connect(screen, &QScreen::geometryChanged, this, QOverload<const QRect &>::of(&DesktopIconView::setGeometry));
-            setGeometry(screen->geometry());
-    //        qDebug() << "name: " << screen->name() << " --- " << screen->availableGeometry();
-        });
-    }
-
-    for (auto i = screens.constBegin(); i != screens.constEnd(); ++i) {
-        m_screens[*i] = (*i == qApp->primaryScreen()) ? true : false;
-    }
-
     m_model = new DesktopItemModel(this);
     m_proxy_model = new DesktopItemProxyModel(m_model);
 
@@ -214,19 +150,6 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
         }
     });
 
-    connect(m_proxy_model, &QAbstractItemModel::rowsRemoved, this, [=](){
-        auto itemsNeedRelayout = m_model->m_items_need_relayout;
-        if (!itemsNeedRelayout.isEmpty()) {
-            this->relayoutExsitingItems(itemsNeedRelayout);
-        }
-
-        for (auto uri : getAllFileUris()) {
-            auto pos = getFileMetaInfoPos(uri);
-            if (pos.x() >= 0)
-                updateItemPosByUri(uri, pos);
-        }
-    });
-
     //connect(m_model, &DesktopItemModel::dataChanged, this, &DesktopIconView::clearAllIndexWidgets);
 
     connect(m_model, &DesktopItemModel::refreshed, this, [=]() {
@@ -324,7 +247,7 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
             }
 
             // check icon is out of screen
-            auto geo = getScreenArea(qApp->primaryScreen());
+            auto geo = viewport()->rect();
             if (geo.width() != 0 && geo.height() != 0) {
                 for (auto rec : m_item_rect_hash.values()) {
                     if (!geo.contains(rec)) {
@@ -335,7 +258,6 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
             }
         });
 
-
         return;
     });
 
@@ -357,7 +279,7 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
             }
         }
 
-        auto geo = getScreenArea(qApp->primaryScreen());
+        auto geo = viewport()->rect();
         if (geo.width() != 0 && geo.height() != 0) {
             QModelIndex index = m_proxy_model->mapToSource(m_model->indexFromUri(uri));
             QRect indexRect = QListView::visualRect(index);
@@ -384,13 +306,20 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
         });
     });
 
+    connect(m_proxy_model, &DesktopItemProxyModel::showHiddenFile, this, [=]() {
+        QTimer::singleShot(100, this, [=]() {
+            resetAllItemPositionInfos();
+            refresh();
+        });
+    });
+
     connect(this, &QListView::iconSizeChanged, this, [=]() {
         //qDebug()<<"save=============";
         this->setSortType(GlobalSettings::getInstance()->getValue(LAST_DESKTOP_SORT_ORDER).toInt());
 
         QTimer::singleShot(100, this, [=]() {
             bool isFull = false;
-            auto geo = getScreenArea(qApp->primaryScreen());
+            auto geo = viewport()->rect();
             this->saveAllItemPosistionInfos();
             for (int i = 0; i < m_proxy_model->rowCount(); i++) {
                 auto index = m_proxy_model->index(i, 0);
@@ -424,28 +353,25 @@ DesktopIconView::DesktopIconView(QWidget *parent) : QListView(parent)
         //panel monitor
         QGSettings *panelSetting = new QGSettings(PANEL_SETTINGS, QByteArray(), this);
         connect(panelSetting, &QGSettings::changed, this, [=](const QString &key){
-            if (key == "panelposition" || key == "panelsize") {
+            if (key == "panelposition" || key == "panelsize")
+            {
                 int position = panelSetting->get("panelposition").toInt();
                 int margins = panelSetting->get("panelsize").toInt();
                 switch (position) {
                 case 1: {
                     setViewportMargins(0, margins, 0, 0);
-                    m_panel_margin = QMargins(0, margins, 0, 0);
                     break;
                 }
                 case 2: {
                     setViewportMargins(margins, 0, 0, 0);
-                    m_panel_margin = QMargins(margins, 0, 0, 0);
                     break;
                 }
                 case 3: {
                     setViewportMargins(0, 0, margins, 0);
-                    m_panel_margin = QMargins(0, 0, margins, 0);
                     break;
                 }
                 default: {
                     setViewportMargins(0, 0, 0, margins);
-                    m_panel_margin = QMargins(0, 0, 0, margins);
                     break;
                 }
                 }
@@ -690,7 +616,6 @@ void DesktopIconView::initShoutCut()
     showHiddenAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_H));
     addAction(showHiddenAction);
     connect(showHiddenAction, &QAction::triggered, this, [=]() {
-        //qDebug() << "show hidden";
         this->setShowHidden();
     });
 
@@ -729,7 +654,7 @@ void DesktopIconView::initMenu()
                 auto action = menu.addAction(tr("set background"));
                 connect(action, &QAction::triggered, [=]() {
                     //go to control center set background
-                    DesktopWindow::gotoSetBackground();
+                    PeonyDesktopApplication::gotoSetBackground();
                 });
             }
             menu.exec(QCursor::pos());
@@ -746,8 +671,7 @@ void DesktopIconView::initMenu()
 
 void DesktopIconView::setShowHidden()
 {
-    m_show_hidden = ! m_show_hidden;
-    qDebug() << "DesktopIconView::setShowHidden:" <<m_show_hidden;
+    m_show_hidden = !GlobalSettings::getInstance()->getValue(SHOW_HIDDEN_PREFERENCE).toBool();
     m_proxy_model->setShowHidden(m_show_hidden);
     //fix show hidden file desktop icons overlapped issue
     QTimer::singleShot(100, this, [=]() {
@@ -768,7 +692,7 @@ void DesktopIconView::resolutionChange()
     float iconHeigth = 0;
 
     // icon size
-    QSize icon = QListView::gridSize();
+    QSize icon = gridSize();
     iconWidth = icon.width();
     iconHeigth = icon.height();
 
@@ -1152,7 +1076,7 @@ void DesktopIconView::setSortType(int sortType)
     m_proxy_model->sort(0, m_proxy_model->sortOrder());
     saveAllItemPosistionInfos();
     bool isFull = false;
-    auto geo = getScreenArea(qApp->primaryScreen());
+    auto geo = viewport()->rect();
     if (geo.width() != 0 && geo.height() != 0) {
         for (int i = 0; i < m_proxy_model->rowCount(); i++) {
             auto index = m_proxy_model->index(i, 0);
@@ -1391,6 +1315,7 @@ void DesktopIconView::resizeEvent(QResizeEvent *e)
 
 void DesktopIconView::rowsInserted(const QModelIndex &parent, int start, int end)
 {
+    m_model->relayoutAddedItems();
     QListView::rowsInserted(parent, start, end);
     for (auto uri : getAllFileUris()) {
         auto pos = getFileMetaInfoPos(uri);
@@ -1434,6 +1359,7 @@ void DesktopIconView::rowsInserted(const QModelIndex &parent, int start, int end
 
 void DesktopIconView::rowsAboutToBeRemoved(const QModelIndex &parent, int start, int end)
 {
+    m_model->relayoutAddedItems();
     QListView::rowsAboutToBeRemoved(parent, start, end);
 //    QTimer::singleShot(1, this, [=](){
 //        for (auto uri : getAllFileUris()) {
@@ -1442,7 +1368,6 @@ void DesktopIconView::rowsAboutToBeRemoved(const QModelIndex &parent, int start,
 //                updateItemPosByUri(uri, pos);
 //        }
 //    });
-    m_model->relayoutAddedItems();
 
     for (int row = start; row <= end; row++) {
         auto uri = model()->index(row, 0).data(Qt::UserRole).toString();
@@ -1891,7 +1816,10 @@ void DesktopIconView::dropEvent(QDropEvent *e)
 
             m_model->dropMimeData(e->mimeData(), action, -1, -1, this->indexAt(e->pos()));
         } else {
+            // do not trigger file operation, link to: #66345
+            m_model->setAcceptDropAction(false);
             QListView::dropEvent(e);
+            m_model->setAcceptDropAction(true);
         }
 
         QRegion dirtyRegion;
@@ -2115,6 +2043,10 @@ void DesktopIconView::clearAllIndexWidgets(const QStringList &uris)
         row++;
         index = model()->index(row, 0);
     }
+
+    // avoid dirty region out of index visual rect.
+    // link to: #77272.
+    viewport()->update();
 }
 
 void DesktopIconView::refresh()
@@ -2137,7 +2069,6 @@ void DesktopIconView::refresh()
 QRect DesktopIconView::visualRect(const QModelIndex &index) const
 {
     auto rect = QListView::visualRect(index);
-
     QPoint p(10, 5);
 
     switch (zoomLevel()) {
@@ -2153,7 +2084,6 @@ QRect DesktopIconView::visualRect(const QModelIndex &index) const
     default:
         break;
     }
-
     rect.moveTo(rect.topLeft() + p);
     return rect;
 }
@@ -2169,46 +2099,6 @@ int DesktopIconView::updateBWList()
     return 0;
 }
 
-QRect DesktopIconView::getScreenArea(QScreen *screen)
-{
-    if (!screen) return QRect(0, 0, 0, 0);
-
-    if (m_panel_margin.isNull()) {
-        if (QGSettings::isSchemaInstalled(PANEL_SETTINGS)) {
-            QGSettings *panelSetting = new QGSettings(PANEL_SETTINGS, QByteArray(), this);
-            int pos = panelSetting->get("panelposition").toInt();
-            int size = panelSetting->get("panelsize").toInt();
-
-            switch (pos) {
-            case 1: {
-                m_panel_margin = QMargins(0, size, 0, 0);
-                break;
-            }
-            case 2: {
-                m_panel_margin = QMargins(size, 0, 0, 0);
-                break;
-            }
-            case 3: {
-                m_panel_margin = QMargins(0, 0, size, 0);
-                break;
-            }
-            default: {
-                m_panel_margin = QMargins(0, 0, 0, size);
-                break;
-            }
-            }
-            panelSetting->deleteLater();
-        }
-    }
-
-    QRect geo = screen->geometry();
-
-    geo.adjust(m_panel_margin.left(), m_panel_margin.top(), -m_panel_margin.right(), -m_panel_margin.bottom());
-
-    return geo;
-}
-
-
 static bool iconSizeLessThan (const QPair<QRect, QString>& p1, const QPair<QRect, QString>& p2)
 {
     if (p1.first.x() > p2.first.x())
