@@ -38,6 +38,9 @@
 
 #include <QDebug>
 
+//qt's global function
+extern void qt_blurImage(QImage &blurImage, qreal radius, bool quality, int transposed);
+
 using namespace Peony;
 
 DesktopIndexWidget::DesktopIndexWidget(DesktopIconViewDelegate *delegate,
@@ -51,8 +54,6 @@ DesktopIndexWidget::DesktopIndexWidget(DesktopIconViewDelegate *delegate,
     m_index = index;
     m_delegate = delegate;
 
-    m_current_font = QApplication::font();
-
     updateItem();
 
     //FIXME: how to handle it in old version?
@@ -73,9 +74,30 @@ DesktopIndexWidget::~DesktopIndexWidget()
 
 }
 
+bool DesktopIndexWidget::eventFilter(QObject *watched, QEvent *event)
+{
+    switch (event->type()) {
+    case QEvent::ApplicationFontChange:
+    case QEvent::FontChange: {
+        updateItem();
+        break;
+    }
+    default:
+        break;
+    }
+    return false;
+}
+
 void DesktopIndexWidget::paintEvent(QPaintEvent *e)
 {
     auto view = m_delegate->getView();
+    //qDebug()<<"paint";
+    auto visualRect = m_delegate->getView()->visualRect(m_index);
+    if (this->pos() != visualRect.topLeft()) {
+        move(visualRect.topLeft());
+        return;
+    }
+
     if (!view->selectionModel()->selectedIndexes().contains(m_index)) {
         view->m_real_do_edit = false;
         view->m_edit_trigger_timer.stop();
@@ -83,10 +105,6 @@ void DesktopIndexWidget::paintEvent(QPaintEvent *e)
         return;
     }
 
-    //qDebug()<<"paint";
-    auto visualRect = m_delegate->getView()->visualRect(m_index);
-    move(visualRect.topLeft());
-
     Q_UNUSED(e)
     QPainter p(this);
     auto bgColor = m_option.palette.highlight().color();
@@ -105,6 +123,8 @@ void DesktopIndexWidget::paintEvent(QPaintEvent *e)
     int y_delta = iconSizeExcepted.height() - iconRect.height();
     opt.rect.moveTo(opt.rect.x(), opt.rect.y() + y_delta);
 
+    int maxTextHight = this->height() - iconSizeExcepted.height() - 10;
+
     //setFixedHeight(opt.rect.height() + y_delta);
 
     // draw icon
@@ -121,26 +141,36 @@ void DesktopIndexWidget::paintEvent(QPaintEvent *e)
     }
     // draw text shadow
     p.save();
-    p.translate(1, 1);
-    QColor shadow = Qt::black;
-    shadow.setAlpha(127);
-    p.setPen(shadow);
-    Peony::DirectoryView::IconViewTextHelper::paintText(&p,
-            m_option,
-            m_index,
-            9999,
-            2,
-            0,
-            false);
-//    QFontMetrics fm(m_current_font);
 
-//    style()->drawItemText(&p,
-//                          m_text_rect,
-//                          Qt::AlignTop|Qt::TextWrapAnywhere|Qt::AlignHCenter,
-//                          this->palette(),
-//                          true,
-//                          m_option.text,
-//                          QPalette::Shadow);
+    auto expectedSize = Peony::DirectoryView::IconViewTextHelper::getTextSizeForIndex(m_option, m_index, 2);
+    QPixmap pixmap(expectedSize);
+    pixmap.fill(Qt::transparent);
+    QPainter shadowPainter(&pixmap);
+    shadowPainter.setPen(Qt::black);
+    Peony::DirectoryView::IconViewTextHelper::paintText(&shadowPainter, m_option, m_index, maxTextHight, 2, 0, false, Qt::black);
+    shadowPainter.end();
+
+    QImage shadowImage(expectedSize + QSize(4, 4), QImage::Format_ARGB32_Premultiplied);
+    shadowImage.fill(Qt::transparent);
+    shadowPainter.begin(&shadowImage);
+    shadowPainter.drawPixmap(2, 2, pixmap);
+    qt_blurImage(shadowImage, 8, false, false);
+
+    for (int x = 0; x < shadowImage.width(); x++) {
+        for (int y = 0; y < shadowImage.height(); y++) {
+            auto color = shadowImage.pixelColor(x, y);
+            if (color.alpha() > 0) {
+                color.setAlphaF(qMin(color.alphaF() * 1.5, 1.0));
+                shadowImage.setPixelColor(x, y, color);
+            }
+        }
+    }
+
+    shadowPainter.end();
+
+    p.translate(-3, -1);
+    p.drawImage(0, 0, shadowImage);
+
     p.restore();
 
     // draw text
@@ -150,15 +180,9 @@ void DesktopIndexWidget::paintEvent(QPaintEvent *e)
             m_index,
             9999,
             2,
-            0,
+            4,
             false);
-//    style()->drawItemText(&p,
-//                          m_text_rect,
-//                          Qt::AlignTop|Qt::TextWrapAnywhere|Qt::AlignHCenter,
-//                          this->palette(),
-//                          true,
-//                          m_option.text,
-//                          QPalette::HighlightedText);
+
     p.restore();
 
     bgColor.setAlpha(255*0.8);
@@ -225,7 +249,7 @@ void DesktopIndexWidget::mouseDoubleClickEvent(QMouseEvent *event)
         return;
     }
 
-    m_delegate->getView()->doubleClicked(m_index);
+    m_delegate->getView()->activated(m_index);
     m_delegate->getView()->setIndexWidget(m_index, nullptr);
     return;
 }
@@ -234,6 +258,8 @@ void DesktopIndexWidget::updateItem()
 {
     auto view = m_delegate->getView();
     m_option = view->viewOptions();
+    m_option.font = qApp->font();
+    m_option.fontMetrics = qApp->fontMetrics();
     m_delegate->initStyleOption(&m_option, m_index);
     QSize size = m_delegate->sizeHint(m_option, m_index);
     auto visualRect = m_delegate->getView()->visualRect(m_index);
@@ -286,19 +312,5 @@ void DesktopIndexWidget::updateItem()
     rawTextRect.setTop(iconRect.bottom() + y_delta + 5);
     rawTextRect.setHeight(9999);
 
-    QFontMetrics fm(m_current_font);
-    auto textRect = QApplication::style()->itemTextRect(fm,
-                    rawTextRect,
-                    Qt::AlignTop|Qt::AlignHCenter|Qt::TextWrapAnywhere,
-                    true,
-                    m_option.text);
-
-    m_text_rect = textRect;
-
-    //m_option.font = font;
-    //auto opt = m_option;
-
-    qDebug()<<textRect;
-//    setFixedHeight(textRect.bottom() + 10);
     setFixedHeight(fixedHeight);
 }
