@@ -20,8 +20,8 @@
  *
  */
 
-#include "desktop-window.h"
 #include "peony-desktop-application.h"
+#include "waylandoutputmanager.h"
 
 #include <QDBusMessage>
 #include <QDBusConnection>
@@ -30,6 +30,7 @@
 #include <stdlib.h>
 #include <QTime>
 #include <QFile>
+#include <QThread>
 
 #include <QStandardPaths>
 
@@ -91,10 +92,18 @@ int main(int argc, char *argv[])
     QApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
 #endif
 
-    PeonyDesktopApplication a(argc, argv);
-    if (a.isSecondary())
+    QString id = "peony-qt-desktop" + qgetenv("DISPLAY");
+    PeonyDesktopApplication a(argc, argv, id);
+    if (a.isRunning())
         return 0;
 
+//    WaylandOutputManager waylandOutputManager;
+//    QThread waylandThread;
+//    waylandOutputManager.moveToThread(&waylandThread);
+//    QObject::connect(&waylandThread, &QThread::started, &waylandOutputManager, &WaylandOutputManager::run);
+//    QObject::connect(&a, &PeonyDesktopApplication::requestSetUKUIOutputEnable, &waylandOutputManager, &WaylandOutputManager::setUKUIOutputEnable);
+//    waylandThread.start();
+
     QDBusMessage message = QDBusMessage::createMethodCall("org.gnome.SessionManager",
                                                           "/org/gnome/SessionManager",
                                                           "org.gnome.SessionManager",
