@@ -25,7 +25,7 @@
 #include "side-bar-proxy-filter-sort-model.h"
 #include "side-bar-abstract-item.h"
 #include "volume-manager.h"
-
+#include "volumeManager.h"
 #include "side-bar-menu.h"
 #include "side-bar-abstract-item.h"
 #include "bookmark-manager.h"
@@ -63,6 +63,7 @@
 #include <QPainterPath>
 
 #include <QDebug>
+#include <QToolTip>
 
 #define NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS 4
 
@@ -72,6 +73,8 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
 {
     static NavigationSideBarStyle *global_style = new NavigationSideBarStyle;
 
+    setSortingEnabled(true);
+
     setIconSize(QSize(16, 16));
 
     setProperty("useIconHighlightEffect", true);
@@ -115,12 +118,19 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
 
     this->setModel(m_proxy_model);
 
+    setMouseTracking(true);//追踪鼠标
+
     VolumeManager *volumeManager = VolumeManager::getInstance();
     connect(volumeManager,&Peony::VolumeManager::volumeAdded,this,[=](const std::shared_ptr<Peony::Volume> &volume){
         m_proxy_model->invalidate();//display DVD device in real time.
     });
     connect(volumeManager,&Peony::VolumeManager::volumeRemoved,this,[=](const std::shared_ptr<Peony::Volume> &volume){
         m_proxy_model->invalidate();//The drive does not display when the DVD device is removed.
+        //qDebug() << "volumeRemoved:" <<QToolTip::text();
+        //fix abnormal pull out usb device tips not hide issue, link to bug#81190
+        if (QToolTip::isVisible()) {
+            QToolTip::hideText();
+        }
     });
     connect(volumeManager,&Peony::VolumeManager::driveDisconnected,this,[=](const std::shared_ptr<Peony::Drive> &drive){
         m_proxy_model->invalidate();//Multiple udisk eject display problem
@@ -143,19 +153,26 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
         item->clearChildren();
     });
 
+    connect(Experimental_Peony::VolumeManager::getInstance(), &Experimental_Peony::VolumeManager::signal_mountFinished,this,[=](){
+        JumpDirectory(m_currSelectedItem->uri());
+        qDebug()<<"挂载后跳转路径："<<m_currSelectedItem->uri();
+    });
+
     connect(this, &QTreeView::clicked, [=](const QModelIndex &index) {
         switch (index.column()) {
         case 0: {
-            auto item = m_proxy_model->itemFromIndex(index);
-            //some side bar item doesn't have a uri.
-            //do not emit signal with a null uri to window.
-            if (!item->uri().isNull())
-                Q_EMIT this->updateWindowLocationRequest(item->uri());
+            m_currSelectedItem = m_proxy_model->itemFromIndex(index);
+            if(m_currSelectedItem->isMountable()&&!m_currSelectedItem->isMounted())
+                m_currSelectedItem->mount();
+            else{
+                JumpDirectory(m_currSelectedItem->uri());
+            }
             break;
+
         }
         case 1: {
             auto item = m_proxy_model->itemFromIndex(index);
-            if (item->isMounted() || item->isEjectable()) {
+            if (item->isMounted() || item->isEjectable()||item->isStopable()) {
                 auto leftIndex = m_proxy_model->index(index.row(), 0, index.parent());
                 this->collapse(leftIndex);
                 item->ejectOrUnmount();
@@ -253,7 +270,8 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
                     if ((0 != QString::compare(item->uri(), "computer:///")) &&
                         (0 != QString::compare(item->uri(), "filesafe:///"))) {
                         for (const auto &actionItem : actionList) {
-                            actionItem->setEnabled(item->isMounted());
+                            if(item->isMountable()||item->isUnmountable())/* 分区才去需要判断是否已挂载 */
+                                actionItem->setEnabled(item->isMounted());
                         }
                     }
                 }
@@ -267,7 +285,7 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
         this->viewport()->update();
     });
 
-    expandAll();
+    expandToDepth(1);/* 快速访问、计算机、网络 各模块往下展开一层 */
 }
 
 bool NavigationSideBar::eventFilter(QObject *obj, QEvent *e)
@@ -321,6 +339,9 @@ void NavigationSideBar::dropEvent(QDropEvent *e)
         auto bookmark = Peony::BookMarkManager::getInstance();
         if (bookmark->isLoaded()) {
             for (auto url : data->urls()) {
+                if(url.toString().startsWith("filesafe:///")){
+                    continue;
+                }
                 //FIXME: replace BLOCKING api in ui thread.
                 auto info = Peony::FileInfo::fromUri(url.toDisplayString());
                 if (info->displayName().isNull()) {
@@ -348,6 +369,32 @@ QSize NavigationSideBar::sizeHint() const
     return QTreeView::sizeHint();
 }
 
+void NavigationSideBar::JumpDirectory(const QString &uri)
+{
+    auto info = FileInfo::fromUri(uri);
+    if (info.get()->isEmptyInfo()) {
+        FileInfoJob j(info);
+        j.querySync();
+    }
+    auto targetUri = FileUtils::getTargetUri(uri);
+    if (targetUri == "" && uri== "burn://" /*&& item->displayName().contains("DVD")*/)
+    {
+        qDebug() << "empty drive"<<uri;
+        QMessageBox::information(nullptr, tr("Tips"), tr("This is an empty drive, please insert a Disc."));
+        return;
+    }
+
+    if (!targetUri.isEmpty()) {
+        Q_EMIT this->updateWindowLocationRequest(targetUri);
+        return;
+    }
+
+    //some side bar item doesn't have a uri.
+    //do not emit signal with a null uri to window.
+    if (!uri.isNull())
+        Q_EMIT this->updateWindowLocationRequest(uri);
+}
+
 void NavigationSideBar::keyPressEvent(QKeyEvent *event)
 {
     QTreeView::keyPressEvent(event);
