@@ -52,6 +52,13 @@ public:
 
     static qint64 peony_start_time;
 
+public Q_SLOTS:
+    //unmount all ftp links
+    void unmountAllFtpLinks();
+
+private:
+    QString getUriMessage (QStringList&);
+
 protected Q_SLOTS:
     void parseCmd(quint32 id, QByteArray msg);
 
